@@ -21,6 +21,7 @@ This file is part of C.a.R. software.
  
  package eric;
 
+import eric.GUI.pipe_tools;
 import java.awt.BasicStroke;
 import java.awt.Color;
 import java.awt.Component;
@@ -40,7 +41,7 @@ import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JDialog;
 import javax.swing.JLabel;
-import javax.swing.JPanel;
+import eric.JEricPanel;
 import javax.swing.SwingConstants;
 
 import net.java.dev.colorchooser.ColorChooser;
@@ -51,7 +52,7 @@ import rene.gui.Global;
  * 
  * @author erichake
  */
-public class JGlobalPreferencesColor extends JPanel implements MouseListener,
+public class JGlobalPreferencesColor extends JEricPanel implements MouseListener,
 MouseMotionListener {
 	/**
 	 * 
@@ -66,7 +67,7 @@ MouseMotionListener {
 	JGlobalPreferencesColor me;
 	JComboBox JCB;
 	JLabel comment;
-	JPanel colorsample = new JPanel();
+	JEricPanel colorsample = new JEricPanel();
 
 	@Override
 	public void paintComponent(final java.awt.Graphics g) {
@@ -108,7 +109,7 @@ MouseMotionListener {
 		JCB.addItem(Loc("constants"));
 		JCB.setSelectedIndex(PaletteType);
 		JCB.addItemListener(new ItemAdapter());
-		final JPanel JCBpanel = new JPanel();
+		final JEricPanel JCBpanel = new JEricPanel();
 		JCBpanel.setLayout(new BoxLayout(JCBpanel, BoxLayout.X_AXIS));
 		JCBpanel.setAlignmentX(0.5f);
 		JCBpanel.setOpaque(false);
@@ -134,7 +135,7 @@ MouseMotionListener {
 	}
 
 	public String Loc(final String s) {
-		return JMacrosTools.CurrentJZF.Strs.getString("palette.colors." + s);
+		return Global.Loc("palette.colors." + s);
 	}
 
 	class ItemAdapter implements ItemListener {
@@ -171,12 +172,12 @@ MouseMotionListener {
 		return GetDialog(c.getParent());
 	}
 
-	class colorline extends JPanel {
+	class colorline extends JEricPanel {
 		/**
 		 * 
 		 */
 		private static final long serialVersionUID = 1L;
-		JPanel mymargin;
+		JEricPanel mymargin;
 		onlycolors mycolors;
 
 		colorline(final int ptype) {
@@ -196,7 +197,7 @@ MouseMotionListener {
 
 	}
 
-	private class onlycolors extends JPanel {
+	private class onlycolors extends JEricPanel {
 		/**
 		 * 
 		 */
@@ -246,7 +247,7 @@ MouseMotionListener {
 			final int w = (PW < Pal.getSize().width) ? PW : Pal.getSize().width;
 			fixsize(this, w, Pal.getSize().height);
 			// bimage=JPM.MW.createImage(Pal.getSize().width,Pal.getSize().height);
-			bimage = JMacrosTools.CurrentJZF.createImage(Pal.getSize().width,
+			bimage = this.createImage(Pal.getSize().width,
 					Pal.getSize().height);
 			Pal.paintTo(bimage.getGraphics());
 			this.setLayout(new BoxLayout(this, BoxLayout.X_AXIS));
@@ -274,16 +275,16 @@ MouseMotionListener {
 		cp.setSize(d);
 	}
 
-	private JPanel margin(final int w) {
-		final JPanel mypan = new JPanel();
+	private JEricPanel margin(final int w) {
+		final JEricPanel mypan = new JEricPanel();
 		fixsize(mypan, w, 1);
 		mypan.setOpaque(false);
 		mypan.setFocusable(false);
 		return mypan;
 	}
 
-	private JPanel margintop(final int h) {
-		final JPanel mypan = new JPanel();
+	private JEricPanel margintop(final int h) {
+		final JEricPanel mypan = new JEricPanel();
 		fixsize(mypan, 1, h);
 		mypan.setOpaque(false);
 		mypan.setFocusable(false);
