@@ -38,15 +38,16 @@ import javax.swing.JButton;
 import javax.swing.JComponent;
 import javax.swing.JDialog;
 import javax.swing.JLabel;
-import javax.swing.JPanel;
 import javax.swing.JTextField;
 import javax.swing.SwingConstants;
 
-import rene.zirkel.Zirkel;
+import rene.gui.Global;
 import rene.zirkel.ZirkelCanvas;
 import rene.zirkel.expression.Expression;
 import rene.zirkel.objects.ConstructionObject;
 import eric.bar.JProperties;
+import javax.swing.JPanel;
+import rene.gui.Global;
 
 /**
  * 
@@ -76,8 +77,8 @@ public class JMacroPrompt extends JDialog {
 		cp.setSize(d);
 	}
 
-	private JPanel margin(final int w) {
-		final JPanel mypan = new JPanel();
+	private JEricPanel margin(final int w) {
+		final JEricPanel mypan = new JEricPanel();
 		fixsize(mypan, w, 1);
 		mypan.setOpaque(false);
 		mypan.setFocusable(false);
@@ -116,22 +117,22 @@ public class JMacroPrompt extends JDialog {
 		// this.setBackground(new Color(0.2f, 0.2f, 0.2f, 0.5f));
 		// content.setOpaque(false);
 
-		final JLabel p1 = new JLabel(Zirkel.name("macro.prompt.prompt") + " :");
+		final JLabel p1 = new JLabel(Global.name("macro.prompt.prompt") + " :");
 		p1.setHorizontalAlignment(SwingConstants.CENTER);
 		fixsize(p1, 300, 15);
 		p1.setAlignmentX(0.5f);
 		p1.setOpaque(false);
-		p1.setFont(new java.awt.Font(JGlobals.GlobalFont, 1, 12));
+		p1.setFont(new java.awt.Font(Global.GlobalFont, 1, 12));
 		p1.setForeground(TitleColor);
 
-		final JPanel p2 = new JPanel();
+		final JEricPanel p2 = new JEricPanel();
 		p2
 		.setLayout(new javax.swing.BoxLayout(p2,
 				javax.swing.BoxLayout.X_AXIS));
 		final JLabel p21 = new JLabel(oName);
 		final JButton okbtn = new JButton();
 		okbtn.setIcon(new ImageIcon(getClass().getResource(
-				"/eric/icons/palette/Mvalid.png")));
+				"/eric/GUI/icons/palette/Mvalid.png")));
 		okbtn.setBorder(BorderFactory.createEmptyBorder());
 		okbtn.addMouseListener(new MouseAdapter() {
 			@Override
@@ -142,7 +143,7 @@ public class JMacroPrompt extends JDialog {
 		okbtn.setContentAreaFilled(false);
 		final JButton cancelbtn = new JButton();
 		cancelbtn.setIcon(new ImageIcon(getClass().getResource(
-		"/eric/icons/palette/Mcancel.png")));
+		"/eric/GUI/icons/palette/Mcancel.png")));
 		cancelbtn.setBorder(BorderFactory.createEmptyBorder());
 		cancelbtn.addMouseListener(new MouseAdapter() {
 			@Override
@@ -177,8 +178,8 @@ public class JMacroPrompt extends JDialog {
 		p2.setAlignmentX(0.5f);
 		p2.setOpaque(false);
 		p21.setOpaque(false);
-		p21.setFont(new java.awt.Font(JGlobals.GlobalFont, 1, 12));
-		T.setFont(new java.awt.Font(JGlobals.GlobalFont, 1, 12));
+		p21.setFont(new java.awt.Font(Global.GlobalFont, 1, 12));
+		T.setFont(new java.awt.Font(Global.GlobalFont, 1, 12));
 		p21.setForeground(TxtColor);
 		T.setText(JProperties.Point_To_Comma(InitValue, OC.getConstruction(),
 				true));
