@@ -34,7 +34,7 @@ import java.awt.GraphicsEnvironment;
 import java.awt.GridLayout;
 import java.awt.TextField;
 
-import javax.swing.JPanel;
+import eric.JEricPanel;
 
 import rene.gui.ButtonAction;
 import rene.gui.CheckboxAction;
@@ -103,13 +103,13 @@ public class FontEditor extends CloseDialog {
 		super(f, Global.name("fonteditor.title"), true);
 		FontTag = fonttag;
 		setLayout(new BorderLayout());
-		final JPanel p = new MyPanel();
+		final JEricPanel p = new MyPanel();
 		p.setLayout(new GridLayout(0, 2));
 		p.add(new MyLabel(Global.name("fonteditor.name")));
 		p.add(FontName = new TextFieldAction(this, "FontName"));
 		FontName.setText(Global.getParameter(fonttag + ".name", fontdef));
 		p.add(new MyLabel(Global.name("fonteditor.available")));
-		p.add(Fonts = new ChoiceAction(this, "Fonts"));
+//		p.add(Fonts = new ChoiceAction(this, "Fonts"));
 		final String[] fonts = GraphicsEnvironment
 		.getLocalGraphicsEnvironment().getAvailableFontFamilyNames();
 		// String[] fonts=Toolkit.getDefaultToolkit().getFontList();
@@ -129,7 +129,7 @@ public class FontEditor extends CloseDialog {
 		Fonts.add("Helvetica");
 		Fonts.select(FontName.getText());
 		p.add(new MyLabel(Global.name("fonteditor.mode")));
-		p.add(Mode = new ChoiceAction(this, "Mode"));
+//		p.add(Mode = new ChoiceAction(this, "Mode"));
 		Mode.add(Global.name("fonteditor.plain"));
 		Mode.add(Global.name("fonteditor.bold"));
 		Mode.add(Global.name("fonteditor.italic"));
@@ -152,7 +152,7 @@ public class FontEditor extends CloseDialog {
 		add("North", new Panel3D(p));
 		Example = new ExampleCanvas(this);
 		add("Center", new Panel3D(Example));
-		final JPanel bp = new MyPanel();
+		final JEricPanel bp = new MyPanel();
 		bp.add(new ButtonAction(this, Global.name("OK"), "OK"));
 		bp.add(new ButtonAction(this, Global.name("close"), "Close"));
 		add("South", new Panel3D(bp));
