@@ -39,7 +39,7 @@ import java.io.File;
 import java.io.FilenameFilter;
 import java.util.Enumeration;
 
-import javax.swing.JPanel;
+import eric.JEricPanel;
 
 import rene.gui.ButtonAction;
 import rene.gui.CloseDialog;
@@ -121,7 +121,7 @@ FilenameFilter, MouseListener { // java.awt.List Dirs,Files;
 		Chosen.setEditable(false);
 
 		// center panels
-		final JPanel center = new MyPanel();
+		final JEricPanel center = new MyPanel();
 		center.setLayout(new GridLayout(1, 2, 5, 0));
 		Dirs = new Lister();
 		if (Global.NormalFont != null)
@@ -138,16 +138,16 @@ FilenameFilter, MouseListener { // java.awt.List Dirs,Files;
 		add("Center", new Panel3D(center));
 
 		// south panel
-		final JPanel south = new MyPanel();
+		final JEricPanel south = new MyPanel();
 		south.setLayout(new BorderLayout());
 
-		final JPanel px = new MyPanel();
+		final JEricPanel px = new MyPanel();
 		px.setLayout(new BorderLayout());
 
-		final JPanel p0 = new MyPanel();
+		final JEricPanel p0 = new MyPanel();
 		p0.setLayout(new GridLayout(0, 1));
 
-		final JPanel p1 = new MyPanel();
+		final JEricPanel p1 = new MyPanel();
 		p1.setLayout(new BorderLayout());
 		p1.add("North", linePanel(new MyLabel(Global.name("myfiledialog.dir")),
 				DirField = new HistoryTextField(this, "Dir", 32) {
@@ -174,7 +174,7 @@ FilenameFilter, MouseListener { // java.awt.List Dirs,Files;
 				DirHistory = new HistoryTextFieldChoice(DirField)));
 		p0.add(new Panel3D(p1));
 
-		final JPanel p2 = new MyPanel();
+		final JEricPanel p2 = new MyPanel();
 		p2.setLayout(new BorderLayout());
 		p2.add("North", linePanel(
 				new MyLabel(Global.name("myfiledialog.file")),
@@ -193,10 +193,10 @@ FilenameFilter, MouseListener { // java.awt.List Dirs,Files;
 
 		south.add("Center", px);
 
-		final JPanel buttons = new MyPanel();
+		final JEricPanel buttons = new MyPanel();
 		buttons.setLayout(new FlowLayout(FlowLayout.RIGHT));
-		buttons.add(Home = new ButtonAction(this, Global.name(
-				"myfiledialog.home", "Home"), "Home"));
+//		buttons.add(Home = new ButtonAction(this, Global.name(
+//				"myfiledialog.home", "Home"), "Home"));
 		buttons.add(new ButtonAction(this, Global.name("myfiledialog.mkdir",
 		"Create Directory"), "Create"));
 		buttons.add(new ButtonAction(this, Global.name("myfiledialog.back",
@@ -226,8 +226,8 @@ FilenameFilter, MouseListener { // java.awt.List Dirs,Files;
 		Home.addMouseListener(this);
 	}
 
-	JPanel linePanel(final Component x, final Component y) {
-		final JPanel p = new MyPanel();
+	JEricPanel linePanel(final Component x, final Component y) {
+		final JEricPanel p = new MyPanel();
 		p.setLayout(new GridLayout(1, 0));
 		p.add(x);
 		p.add(y);
