@@ -32,7 +32,7 @@ import java.awt.event.FocusEvent;
 import java.io.File;
 import java.util.Enumeration;
 
-import javax.swing.JPanel;
+import eric.JEricPanel;
 
 import rene.gui.ButtonAction;
 import rene.gui.CheckboxAction;
@@ -140,11 +140,11 @@ Enumeration {
 			final String modify, final boolean modifystate) {
 		super(f, Global.name("searchfile.title"), true);
 		setLayout(new BorderLayout());
-		final JPanel north = new MyPanel();
+		final JEricPanel north = new MyPanel();
 		north.setLayout(new BorderLayout());
-		final JPanel northa = new MyPanel();
+		final JEricPanel northa = new MyPanel();
 		northa.setLayout(new BorderLayout());
-		final JPanel north1 = new MyPanel();
+		final JEricPanel north1 = new MyPanel();
 		north1.setLayout(new GridLayout(0, 2));
 		north1.add(new MyLabel(Global.name("searchfile.directory")));
 		north1.add(Dir = new HistoryTextField(this, "Dir", 20));
@@ -152,26 +152,26 @@ Enumeration {
 		north1.add(new MyLabel(Global.name("searchfile.pattern")));
 		north1.add(Pattern = new HistoryTextField(this, "TextAction", 20));
 		northa.add("Center", north1);
-		final JPanel north2 = new MyPanel();
-		north2.add(SearchButton = new ButtonAction(this, Global
-				.name("searchfile.search"), "Search"));
-		north2.add(SearchrekButton = new ButtonAction(this, Global
-				.name("searchfile.searchrek"), "SearchRek"));
+		final JEricPanel north2 = new MyPanel();
+//		north2.add(SearchButton = new ButtonAction(this, Global
+//				.name("searchfile.search"), "Search"));
+//		north2.add(SearchrekButton = new ButtonAction(this, Global
+//				.name("searchfile.searchrek"), "SearchRek"));
 		northa.add("South", north2);
 		north.add("North", northa);
 		add("North", new Panel3D(north));
 		add("Center", new Panel3D(L = new MyList(ListNumber)));
 		L.addActionListener(this);
 		L.setMultipleMode(true);
-		final JPanel south = new MyPanel();
+		final JEricPanel south = new MyPanel();
 		south.setLayout(new FlowLayout(FlowLayout.RIGHT));
 		if (!modify.equals("")) {
 			south.add(Mod = new CheckboxAction(this, modify, ""));
 			Mod.setState(modifystate);
 		}
-		south.add(ActionButton = new ButtonAction(this, action, "Action"));
-		south.add(CloseButton = new ButtonAction(this, Global.name("abort"),
-		"Close"));
+//		south.add(ActionButton = new ButtonAction(this, action, "Action"));
+//		south.add(CloseButton = new ButtonAction(this, Global.name("abort"),
+//		"Close"));
 		add("South", new Panel3D(south));
 		pack();
 		Dir.loadHistory("searchfile.dir");
