@@ -49,7 +49,7 @@ import java.util.StringTokenizer;
 import java.util.Vector;
 
 import javax.swing.JDialog;
-import javax.swing.JPanel;
+import eric.JEricPanel;
 
 class SaveColor extends Color {
 	/**
@@ -82,7 +82,7 @@ interface IconBarElement {
  * A simple separator between icons.
  */
 
-class Separator extends JPanel implements IconBarElement {
+class Separator extends JEricPanel implements IconBarElement {
 	/**
 	 * 
 	 */
@@ -133,7 +133,7 @@ class Separator extends JPanel implements IconBarElement {
  * @author Rene This is the most basic icon, handling mouse presses and display
  *         in activated, pressed, unset or disabled state.
  */
-class BasicIcon extends JPanel implements MouseListener, IconBarElement,
+class BasicIcon extends JEricPanel implements MouseListener, IconBarElement,
 Runnable {
 	/**
 	 * 
@@ -685,7 +685,7 @@ class MultipleStringIcon extends MultipleIcon {
 /**
  * Button to get all icons, when there is not too much space.
  */
-class OverflowButton extends JPanel {
+class OverflowButton extends JEricPanel {
 	/**
 	 * 
 	 */
@@ -1082,10 +1082,6 @@ FocusListener, IconBarListener {
 	public IconBar(final Frame f, final boolean traversefocus) {
 		F = f;
 		TraverseFocus = traversefocus;
-		if (Global.ControlBackground != null)
-			setBackground(Global.ControlBackground);
-		else
-			setBackground(SystemColor.menu);
 		Resource = Global.getParameter("iconpath", "");
 		BasicIcon.Size = Global.getParameter("iconsize", 20);
 		setLayout(null);
@@ -1101,7 +1097,7 @@ FocusListener, IconBarListener {
 
 	public void add(final BasicIcon i) {
 		final java.net.URL myurl = getClass().getResource(
-				"/eric/icons/palette/" + i.Name + ".png");
+				"/eric/GUI/icons/palette/" + i.Name + ".png");
 		if (myurl != null) {
 			super.add(i);
 		} else {
@@ -1527,7 +1523,7 @@ FocusListener, IconBarListener {
 			final String text) {
 		if (F == null || WHelp != null)
 			return;
-		if (rene.zirkel.Zirkel.IsApplet)
+		if (rene.gui.Global.isApplet())
 			return;
 		final Point P = i.getPosition();
 		WHelp = new JDialog(F);
@@ -1537,7 +1533,7 @@ FocusListener, IconBarListener {
 		WHelp.setFocusable(false);
 		WHelp.setFocusableWindowState(false);
 		WHelp.setUndecorated(true);
-		final JPanel p = new JPanel();
+		final JEricPanel p = new JEricPanel();
 		final StringTokenizer t = new StringTokenizer(text, "+");
 		p.setLayout(new GridLayout(0, 1));
 		while (t.hasMoreTokens()) {
@@ -1785,7 +1781,7 @@ FocusListener, IconBarListener {
 		IA.addStateLeft("needsave");
 		IA.addColorIconLeft("color", col);
 		f.add("Center", new IconBarPanel(new Panel3D(IA), new Panel3D(
-				new JPanel())));
+				new JEricPanel())));
 		f.pack();
 		f.center();
 		IA.setIconBarListener(IA);
