@@ -23,9 +23,15 @@ This file is part of C.a.R. software.
 
 import java.awt.MenuItem;
 
-public class MyMenuItem extends MenuItem
-{	public MyMenuItem (String s)
-	{	super(s);
-		if (Global.NormalFont!=null) setFont(Global.NormalFont);
+public class MyMenuItem extends MenuItem {
+	/**
+	 * 
+	 */
+	private static final long serialVersionUID = 1L;
+
+	public MyMenuItem(final String s) {
+		super(s);
+		if (Global.NormalFont != null)
+			setFont(Global.NormalFont);
 	}
 }
