@@ -23,17 +23,15 @@ This file is part of C.a.R. software.
 
 import java.awt.Graphics;
 
-import javax.swing.JPanel;
+import eric.JEricPanel;
 
-public class MyPanel extends JPanel {
+public class MyPanel extends JEricPanel {
 	/**
 	 * 
 	 */
 	private static final long serialVersionUID = 1L;
 
 	public MyPanel() {
-		if (Global.ControlBackground != null)
-			setBackground(Global.ControlBackground);
 		repaint();
 	}
 
