@@ -24,25 +24,25 @@ This file is part of C.a.R. software.
 import java.awt.event.MouseWheelEvent;
 import java.awt.event.MouseWheelListener;
 
-class Wheel
-implements MouseWheelListener
-{	WheelListener V;
+class Wheel implements MouseWheelListener {
+	WheelListener V;
 
-	public Wheel (WheelListener v)
-	{	V=v;
+	public Wheel(final WheelListener v) {
+		V = v;
 	}
-	
-	public void mouseWheelMoved (MouseWheelEvent e)
-	{	if (e.getScrollType()==MouseWheelEvent.WHEEL_BLOCK_SCROLL)
-		{	if (e.getWheelRotation()>0)
+
+	public void mouseWheelMoved(final MouseWheelEvent e) {
+		if (e.getScrollType() == MouseWheelEvent.WHEEL_BLOCK_SCROLL) {
+			if (e.getWheelRotation() > 0)
 				V.pageUp();
 			else
 				V.pageDown();
-		}
-		else
-		{	int n=e.getScrollAmount();
-			if (e.getWheelRotation()>0) V.up(n);
-			else V.down(n);
+		} else {
+			final int n = e.getScrollAmount();
+			if (e.getWheelRotation() > 0)
+				V.up(n);
+			else
+				V.down(n);
 		}
 	}
 }
\ No newline at end of file
