@@ -21,6 +21,6 @@ This file is part of C.a.R. software.
  
  package rene.util.sort;
 
-public interface SortObject
-{	public int compare (SortObject o);
+public interface SortObject {
+	public int compare(SortObject o);
 }
