@@ -21,26 +21,35 @@ This file is part of C.a.R. software.
  
  package rene.util.xml;
 
-public class XmlReaderException extends Exception
-{	String Line;
+public class XmlReaderException extends Exception {
+	/**
+	 * 
+	 */
+	private static final long serialVersionUID = 1L;
+	String Line;
 	int Pos;
 	String S;
-	public XmlReaderException (String s, String line, int pos)
-	{	super(s);
-		S=s;
-		Line=line;
-		Pos=pos;
+
+	public XmlReaderException(final String s, final String line, final int pos) {
+		super(s);
+		S = s;
+		Line = line;
+		Pos = pos;
 	}
-	public XmlReaderException (String s)
-	{	this(s,"",0);
+
+	public XmlReaderException(final String s) {
+		this(s, "", 0);
 	}
-	public String getLine ()
-	{	return Line;
+
+	public String getLine() {
+		return Line;
 	}
-	public int getPos ()
-	{	return Pos;
+
+	public int getPos() {
+		return Pos;
 	}
-	public String getText ()
-	{	return S;
+
+	public String getText() {
+		return S;
 	}
 }
