@@ -22,8 +22,7 @@ This file is part of C.a.R. software.
  package rene.zirkel.construction;
 
 import java.util.Vector;
-
-import rene.zirkel.Zirkel;
+import rene.gui.Global;
 import rene.zirkel.ZirkelCanvas;
 import rene.zirkel.ZirkelFrame;
 import rene.zirkel.constructors.AngleConstructor;
@@ -81,13 +80,13 @@ public class Interpreter {
 		{
 			Parameter = true;
 			s = s.substring(k).trim();
-		} else if (s.toLowerCase().equals(Zirkel.name("showall"))
+		} else if (s.toLowerCase().equals(Global.name("showall"))
 				|| s.toLowerCase().equals("showall"))
 			// This will show all objects even, if there are targets
 		{
 			C.ShowAll = true;
 			return;
-		} else if (s.toLowerCase().equals(Zirkel.name("invisible"))
+		} else if (s.toLowerCase().equals(Global.name("invisible"))
 				|| s.toLowerCase().equals("invisible"))
 			// This will superhide all objects
 		{
@@ -107,8 +106,9 @@ public class Interpreter {
 				o.setTarget(true);
 				C.addTarget(o);
 				return;
-			} else
-				Target = true;
+			} else {
+                            Target = true;
+                        }
 		} else if ((k = startTest("prompt", s)) >= 0) {
 			Prompt = true;
 			s = s.substring(k).trim();
@@ -130,8 +130,9 @@ public class Interpreter {
 		if (s.startsWith("\"")) {
 			bracketn = s.indexOf("\"", 1);
 		}
-		if (bracketn < 0)
-			throw new ConstructionException("exception.brackets");
+		if (bracketn < 0) {
+                    throw new ConstructionException("exception.brackets");
+                }
 		if ((n = s.indexOf('(', bracketn)) >= 0) {
 			function = s.substring(0, n).trim();
 			if (function.startsWith("\"") && function.endsWith("\"")
@@ -139,8 +140,9 @@ public class Interpreter {
 				function = function.substring(1, function.length() - 1);
 			}
 			s = s.substring(n + 1).trim();
-			if (!s.endsWith(")"))
-				throw new ConstructionException("exception.brackets");
+			if (!s.endsWith(")")) {
+                            throw new ConstructionException("exception.brackets");
+                        }
 			final char a[] = s.substring(0, s.length() - 1).toCharArray();
 			int ia = 0;
 			int BCount = 0;
@@ -149,30 +151,34 @@ public class Interpreter {
 				while (ia < a.length && (BCount > 0 || a[ia] != ',')) {
 					if (a[ia] == '\"') {
 						ia++;
-						while (ia < a.length && a[ia] != '\"')
-							ia++;
-						if (ia >= a.length)
-							throw new ConstructionException(Zirkel
-									.name("exception.quotes"));
+						while (ia < a.length && a[ia] != '\"') {
+                                                    ia++;
+                                                }
+						if (ia >= a.length) {
+                                                    throw new ConstructionException(Global.name("exception.quotes"));
+                                                }
 						ia++;
 					} else if (a[ia] == '(') {
 						BCount++;
 						ia++;
 					} else if (a[ia] == ')') {
-						if (BCount > 0)
-							BCount--;
-						else
-							throw new ConstructionException(Zirkel
-									.name("exception.brackets"));
-						ia++;
-					} else
+						if (BCount > 0) {
+                                                    BCount--;
+                                                }
+						else {
+                                                    throw new ConstructionException(Global.name("exception.brackets"));
+                                                }
 						ia++;
+					} else {
+                                            ia++;
+                                        }
 				}
 				params[NParams++] = new String(a, ia0, ia - ia0).trim();
 				ia++;
 			}
-		} else
-			function = s;
+		} else {
+                    function = s;
+                }
 		final String f = function;
 
 		// Interpret special functions:
@@ -187,7 +193,7 @@ public class Interpreter {
 				C.setXYW(x, y, w);
 				zc.recompute();
 			} catch (final Exception e) {
-				throw new ConstructionException(Zirkel.name("exception.value"));
+				throw new ConstructionException(Global.name("exception.value"));
 			}
 			return;
 		}
@@ -196,66 +202,71 @@ public class Interpreter {
 		{
 			int i = 0;
 			for (i = 0; i < ZirkelFrame.ColorStrings.length; i++) {
-				if (test(params[0], "colors", ZirkelFrame.ColorStrings[i]))
-					break;
+				if (test(params[0], "colors", ZirkelFrame.ColorStrings[i])) {
+                                    break;
+                                }
 			}
 			if (i < ZirkelFrame.ColorStrings.length) {
 				if (NParams == 2) {
 					final ConstructionObject o = C.find(params[1]);
-					if (o == null)
-						throw new ConstructionException(Zirkel
-								.name("exception.notfound"));
+					if (o == null) {
+						throw new ConstructionException(Global.name("exception.notfound"));
+                                        }
 					o.setColor(i);
 				} else {
 					C.DefaultColor = i;
 				}
-			} else
-				throw new ConstructionException(Zirkel.name("exception.color"));
+			} else {
+				throw new ConstructionException(Global.name("exception.color"));
+                        }
 			return;
 		}
 		if ((NParams == 1 || NParams == 2) && ptest(f, "thickness"))
 			// thickness for objects or default thickness
 		{
-			int i = 0;
+			int i;
 			for (i = 0; i < ZirkelFrame.ColorTypes.length; i++) {
-				if (test(params[0], "color.type", ZirkelFrame.ColorTypes[i]))
+				if (test(params[0], "color.type", ZirkelFrame.ColorTypes[i])) {
 					break;
+                                }
 			}
 			if (i < ZirkelFrame.ColorTypes.length) {
 				if (NParams == 2) {
 					final ConstructionObject o = C.find(params[1]);
-					if (o == null)
-						throw new ConstructionException(Zirkel
-								.name("exception.notfound"));
+					if (o == null) {
+						throw new ConstructionException(Global.name("exception.notfound"));
+                                        }
 					o.setColorType(i);
 				} else {
 					C.DefaultColorType = i;
 				}
-			} else
-				throw new ConstructionException(Zirkel
-						.name("exception.colortype"));
+			} else {
+				throw new ConstructionException(Global.name("exception.colortype"));
+                        }
 			return;
 		}
 		if ((NParams == 1 || NParams == 2) && ptest(f, "type"))
 			// point type for point or default point type
 		{
-			int i = 0;
+			int i;
 			for (i = 0; i < ZirkelFrame.PointTypes.length; i++) {
-				if (test(params[0], "point.type", ZirkelFrame.PointTypes[i]))
+				if (test(params[0], "point.type", ZirkelFrame.PointTypes[i])) {
 					break;
+                                }
 			}
 			if (i < ZirkelFrame.PointTypes.length) {
 				if (NParams == 2) {
 					final ConstructionObject o = C.find(params[1]);
-					if (o == null || !(o instanceof PointObject))
-						throw new ConstructionException(Zirkel
-								.name("exception.notfound"));
+					if (o == null || !(o instanceof PointObject)) {
+						throw new ConstructionException(Global.name("exception.notfound"));
+                                        }
 					((PointObject) o).setType(i);
 				} else {
 					C.DefaultType = i;
 				}
-			} else
-				throw new ConstructionException(Zirkel.name("exception.type"));
+			} else {
+				throw new ConstructionException(Global.name("exception.type"));
+                        }
 			return;
 		}
 		if ((NParams == 1 || NParams == 2) && ptest(f, "partial"))
@@ -263,25 +274,29 @@ public class Interpreter {
 		{
 			if (NParams == 1 && !truecheck(params[0])) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
-				if (o instanceof PrimitiveCircleObject)
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
+				if (o instanceof PrimitiveCircleObject) {
 					((PrimitiveCircleObject) o).setPartial(true);
-				if (o instanceof LineObject)
+                                }
+				if (o instanceof LineObject) {
 					((LineObject) o).setPartial(true);
+                                }
 				return;
 			}
 			final boolean partial = truetest(params[0]);
 			if (NParams == 2) {
 				final ConstructionObject o = C.find(params[1]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
-				if (o instanceof PrimitiveCircleObject)
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
+				if (o instanceof PrimitiveCircleObject) {
 					((PrimitiveCircleObject) o).setPartial(partial);
-				if (o instanceof LineObject)
+                                }
+				if (o instanceof LineObject) {
 					((LineObject) o).setPartial(partial);
+                                }
 			} else {
 				C.Partial = partial;
 				C.PartialLines = partial;
@@ -293,18 +308,18 @@ public class Interpreter {
 		{
 			if (NParams == 1 && !truecheck(params[0])) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setHidden(true);
 				return;
 			}
 			final boolean hidden = truetest(params[0]);
 			if (NParams == 2) {
 				final ConstructionObject o = C.find(params[1]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setHidden(hidden);
 			} else {
 				C.Hidden = hidden;
@@ -316,22 +331,22 @@ public class Interpreter {
 		{
 			if (NParams == 1 && !truecheck(params[0])) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setSuperHidden(true);
 				return;
 			}
 			final boolean hidden = truetest(params[0]);
 			if (NParams == 2) {
 				final ConstructionObject o = C.find(params[1]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setSuperHidden(hidden);
-			} else
-				throw new ConstructionException(Zirkel
-						.name("exception.notfound"));
+			} else {
+				throw new ConstructionException(Global.name("exception.notfound"));
+                        }
 			return;
 		}
 		if (NParams >= 1 && ptest(f, "back"))
@@ -339,17 +354,17 @@ public class Interpreter {
 		{
 			if (NParams == 1) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setBack(true);
 				return;
 			}
 			final boolean back = truetest(params[0]);
 			final ConstructionObject o = C.find(params[1]);
-			if (o == null)
-				throw new ConstructionException(Zirkel
-						.name("exception.notfound"));
+			if (o == null) {
+				throw new ConstructionException(Global.name("exception.notfound"));
+                        }
 			o.setBack(back);
 			return;
 		}
@@ -358,18 +373,18 @@ public class Interpreter {
 		{
 			if (NParams == 1 && !truecheck(params[0])) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setObtuse(false);
 				return;
 			}
 			final boolean acute = truetest(params[0]);
 			if (NParams == 2) {
 				final ConstructionObject o = C.find(params[1]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setObtuse(!acute);
 			} else {
 				C.Obtuse = !acute;
@@ -381,18 +396,18 @@ public class Interpreter {
 		{
 			if (NParams == 1 && !truecheck(params[0])) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+					throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setObtuse(false);
 				return;
 			}
 			final boolean obtuse = truetest(params[0]);
 			if (NParams == 2) {
 				final ConstructionObject o = C.find(params[1]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+                                    throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setObtuse(obtuse);
 			} else {
 				C.Obtuse = obtuse;
@@ -404,18 +419,18 @@ public class Interpreter {
 		{
 			if (NParams == 1 && !truecheck(params[0])) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+                                    throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setSolid(false);
 				return;
 			}
 			final boolean solid = truetest(params[0]);
 			if (NParams == 2) {
 				final ConstructionObject o = C.find(params[1]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+                                    throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setSolid(solid);
 			} else {
 				C.Solid = solid;
@@ -426,13 +441,10 @@ public class Interpreter {
 			// set range for circle arcs
 		{
 			try {
-				final PrimitiveCircleObject c = (PrimitiveCircleObject) C
-				.find(params[0]);
-				if (!c.setRange(params[1], params[2]))
-					throw new Exception("");
+				final PrimitiveCircleObject c = (PrimitiveCircleObject) C.find(params[0]);
+				c.setRange(params[1], params[2]);
 			} catch (final Exception e) {
-				throw new ConstructionException(Zirkel
-						.name("exception.notfound"));
+				throw new ConstructionException(Global.name("exception.notfound"));
 			}
 			return;
 		}
@@ -441,18 +453,18 @@ public class Interpreter {
 		{
 			if (NParams == 1) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+                                    throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setFilled(true);
 				o.setBack(true);
 				return;
 			}
 			final boolean fill = truetest(params[0]);
 			final ConstructionObject o = C.find(params[1]);
-			if (o == null)
-				throw new ConstructionException(Zirkel
-						.name("exception.notfound"));
+			if (o == null) {
+                            throw new ConstructionException(Global.name("exception.notfound"));
+                        }
 			o.setFilled(fill);
 			o.setBack(fill);
 			return;
@@ -462,9 +474,9 @@ public class Interpreter {
 		{
 			if (NParams == 1) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+                                    throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				if (o instanceof PlumbObject) {
 					((PlumbObject) o).setRestricted(false);
 				} else if (o instanceof IntersectionObject) {
@@ -474,9 +486,9 @@ public class Interpreter {
 			}
 			truetest(params[0]);
 			final ConstructionObject o = C.find(params[1]);
-			if (o == null)
-				throw new ConstructionException(Zirkel
-						.name("exception.notfound"));
+			if (o == null) {
+                            throw new ConstructionException(Global.name("exception.notfound"));
+                        }
 			if (o instanceof PlumbObject) {
 				((PlumbObject) o).setRestricted(false);
 			} else if (o instanceof IntersectionObject) {
@@ -489,9 +501,9 @@ public class Interpreter {
 		{
 			if (NParams == 1 && !truecheck(params[0])) {
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+                                    throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setShowName(true);
 				return;
 			}
@@ -500,15 +512,16 @@ public class Interpreter {
 				final boolean shownames = truetest(params[0]);
 				if (NParams == 2) {
 					o = C.find(params[1]);
-					if (o == null)
-						throw new ConstructionException(Zirkel
-								.name("exception.notfound"));
+					if (o == null) {
+                                            throw new ConstructionException(Global.name("exception.notfound"));
+                                        }
 					o.setShowName(truetest(params[0]));
 				} else {
 					C.ShowNames = shownames;
 				}
-			} else if (!params[1].equals(""))
-				o.setName(params[1]);
+			} else if (!params[1].equals("")) {
+                            o.setName(params[1]);
+                        }
 			return;
 		}
 		if (NParams == 2 && ptest(f, "away"))
@@ -516,10 +529,9 @@ public class Interpreter {
 		{
 			final ConstructionObject o = C.find(params[0]);
 			final ConstructionObject p = C.find(params[1]);
-			if (!(o instanceof IntersectionObject)
-					|| !(p instanceof PointObject))
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+			if (!(o instanceof IntersectionObject) || !(p instanceof PointObject)) {
+                            throw new ConstructionException(Global.name("exception.parameter"));
+                        }
 			((IntersectionObject) o).setAway(p.getName());
 			return;
 		}
@@ -529,9 +541,9 @@ public class Interpreter {
 			final ConstructionObject o = C.find(params[0]);
 			final ConstructionObject p = C.find(params[1]);
 			if (!(o instanceof IntersectionObject)
-					|| !(p instanceof PointObject))
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+					|| !(p instanceof PointObject)) {
+                            throw new ConstructionException(Global.name("exception.parameter"));
+                        }
 			((IntersectionObject) o).setAway(p.getName(), false);
 			return;
 		}
@@ -542,9 +554,9 @@ public class Interpreter {
 			if (NParams == 1 && !truecheck(params[0])) // value(o)
 			{
 				final ConstructionObject o = C.find(params[0]);
-				if (o == null)
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+				if (o == null) {
+                                    throw new ConstructionException(Global.name("exception.notfound"));
+                                }
 				o.setShowValue(true);
 				return;
 			}
@@ -554,14 +566,13 @@ public class Interpreter {
 				try {
 					truetest(params[0]);
 				} catch (final Exception e) {
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound"));
+					throw new ConstructionException(Global.name("exception.notfound"));
 				}
 				if (NParams == 2) {
 					o = C.find(params[1]);
-					if (o == null)
-						throw new ConstructionException(Zirkel
-								.name("exception.notfound"));
+					if (o == null) {
+                                            throw new ConstructionException(Global.name("exception.notfound"));
+                                        }
 					o.setShowValue(truetest(params[0]));
 				} else {
 					C.ShowValues = true;
@@ -570,16 +581,16 @@ public class Interpreter {
 			{
 				if (o instanceof SegmentObject) {
 					final SegmentObject os = (SegmentObject) o;
-					if (!os.canFix())
-						throw new ConstructionException(Zirkel
-								.name("exception.canfix"));
+					if (!os.canFix()) {
+                                            throw new ConstructionException(Global.name("exception.canfix"));
+                                        }
 					os.setFixed(true, params[1]);
 					os.validate();
 				} else if (o instanceof CircleObject) {
 					final CircleObject os = (CircleObject) o;
-					if (!os.canFix())
-						throw new ConstructionException(Zirkel
-								.name("exception.canfix"));
+					if (!os.canFix()) {
+                                            throw new ConstructionException(Global.name("exception.canfix"));
+                                        }
 					os.setFixed(true, params[1]);
 					os.validate();
 				} else if (o instanceof FixedCircleObject) {
@@ -588,9 +599,9 @@ public class Interpreter {
 					os.validate();
 				} else if (o instanceof AngleObject) {
 					final AngleObject os = (AngleObject) o;
-					if (!os.canFix())
-						throw new ConstructionException(Zirkel
-								.name("exception.canfix"));
+					if (!os.canFix()) {
+                                            throw new ConstructionException(Global.name("exception.canfix"));
+                                        }
 					os.setFixed(params[1]);
 					os.validate();
 				} else if (o instanceof FixedAngleObject) {
@@ -601,24 +612,24 @@ public class Interpreter {
 					final ExpressionObject os = (ExpressionObject) o;
 					os.setFixed(params[1]);
 					os.validate();
-				} else
-					throw new ConstructionException(Zirkel
-							.name("exception.parameter"));
+				} else {
+                                    throw new ConstructionException(Global.name("exception.parameter"));
+                                }
 			} else if (NParams == 3) // value(P,x,y)
 			{
 				if (o instanceof PointObject) {
 					final PointObject os = (PointObject) o;
-					if (!os.moveablePoint())
-						throw new ConstructionException(Zirkel
-								.name("exception.canfix"));
+					if (!os.moveablePoint()) {
+                                            throw new ConstructionException(Global.name("exception.canfix"));
+                                        }  
 					os.setFixed(params[1], params[2]);
 					os.validate();
-				} else
-					throw new ConstructionException(Zirkel
-							.name("exception.parameter"));
-			} else
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				} else {
+                                    throw new ConstructionException(Global.name("exception.parameter"));
+                                }
+			} else {
+                            throw new ConstructionException(Global.name("exception.parameter"));
+                        }
 			return;
 		}
 
@@ -632,26 +643,26 @@ public class Interpreter {
 
 			// the following are for macro definition in scripts
 			if (Parameter) {
-				if (VN >= V.size())
-					throw new ConstructionException(Zirkel
-							.name("exception.macroparameter"));
-				final ConstructionObject o = C.last();
-				o.setMainParameter();
+				if (VN >= V.size()) {
+                                    throw new ConstructionException(Global.name("exception.macroparameter"));
+                                }
+				final ConstructionObject o = C.lastButN(0);
+				o.setMainParameter(true);
 				if (o.isMainParameter()) {
 					C.addParameter(o);
 					C.Prompts.addElement(comment);
-				} else
-					throw new ConstructionException(Zirkel
-							.name("exception.macroparameter"));
+				} else {
+                                    throw new ConstructionException(Global.name("exception.macroparameter"));
+                                }
 			} else if (Target) {
-				if (VN + 1 != V.size())
-					throw new ConstructionException(Zirkel
-							.name("exception.macrotarget"));
-				final ConstructionObject o = C.last();
+				if (VN + 1 != V.size()) {
+                                    throw new ConstructionException(Global.name("exception.macrotarget"));
+                                }
+				final ConstructionObject o = C.lastButN(0);
 				o.setTarget(true);
 				C.addTarget(o);
 			} else if (Prompt) {
-				final ConstructionObject o = C.last();
+				final ConstructionObject o = C.lastButN(0);
 				C.PromptFor.addElement(o.getName());
 			}
 
@@ -661,23 +672,27 @@ public class Interpreter {
 		// Finally, look for macros:
 		final Macro m = zc.chooseMacro(function);
 		if (m == null) {
-			throw new ConstructionException(Zirkel.name("exception.function"));
+			throw new ConstructionException(Global.name("exception.function"));
 		}
 		MR.setMacro(m, zc);
-		MR.run(zc, C, name, params, NParams);
+
+//                System.out.println("nom:"+m.getName());
+
+                MR.run(zc, C, name, params, NParams);
 
 		// Only for macro definition in scripts
 		if (Target) {
 			final ConstructionObject o = C.find(name);
-			if (o == null)
-				throw new ConstructionException(Zirkel
-						.name("exception.macrotarget"));
+			if (o == null) {
+                            throw new ConstructionException(Global.name("exception.macrotarget"));
+                        }
 			o.setTarget(true);
 			C.addTarget(o);
 		} else if (Prompt) {
 			final ConstructionObject o = C.find(name);
-			if (o != null)
-				C.PromptFor.addElement(o.getName());
+			if (o != null) {
+                            C.PromptFor.addElement(o.getName());
+                        }
 		}
 
 	}
@@ -689,42 +704,49 @@ public class Interpreter {
 
 	static public boolean truetest(String s) throws ConstructionException {
 		s = s.toLowerCase();
-		if (s.equals("true") || s.equals(Zirkel.name("true")))
-			return true;
-		if (s.equals("false") || s.equals(Zirkel.name("false")))
-			return false;
-		throw new ConstructionException(Zirkel.name("exception.boolean"));
+		if (s.equals("true") || s.equals(Global.name("true"))) {
+                    return true;
+                }
+		if (s.equals("false") || s.equals(Global.name("false"))) {
+                    return false;
+                }
+		throw new ConstructionException(Global.name("exception.boolean"));
 	}
 
 	static public boolean truecheck(String s) {
 		s = s.toLowerCase();
-		if (s.equals("true") || s.equals(Zirkel.name("true")))
-			return true;
-		if (s.equals("false") || s.equals(Zirkel.name("false")))
-			return true;
+		if (s.equals("true") || s.equals(Global.name("true"))) {
+                    return true;
+                }
+		if (s.equals("false") || s.equals(Global.name("false"))) {
+                    return true;
+                }
 		return false;
 	}
 
 	static public boolean test(final String f, final String tag, final String s) {
-		return f.equalsIgnoreCase(Zirkel.name(tag + "." + s, ""))
-		|| f.equals(Zirkel.name(tag + ".short." + s, ""))
-		|| f.equals(Zirkel.name(tag + "." + s + ".short", ""))
+		return f.equalsIgnoreCase(Global.name(tag + "." + s, ""))
+		|| f.equals(Global.name(tag + ".short." + s, ""))
+		|| f.equals(Global.name(tag + "." + s + ".short", ""))
 		|| f.equalsIgnoreCase(s);
 	}
 
 	static public int startTest(final String tag, final String s) {
-		int i = startTest0(Zirkel.name(tag, tag).toLowerCase(), s.toLowerCase());
-		if (i > 0)
-			return i;
-		i = startTest0(Zirkel.name(tag + ".short", tag), s);
-		if (i > 0)
-			return i;
+		int i = startTest0(Global.name(tag, tag).toLowerCase(), s.toLowerCase());
+		if (i > 0) {
+                    return i;
+                }
+		i = startTest0(Global.name(tag + ".short", tag), s);
+		if (i > 0) {
+                    return i;
+                }
 		return startTest0(tag, s.toLowerCase());
 	}
 
 	static public int startTest0(final String tag, final String s) {
-		if (s.startsWith(tag + " "))
-			return tag.length() + 1;
+		if (s.startsWith(tag + " ")) {
+                    return tag.length() + 1;
+                }
 		return -1;
 	}
 
@@ -743,18 +765,21 @@ public class Interpreter {
 		if (s.startsWith("c(") && s.endsWith(")")) {
 			s = s.substring(2, s.length() - 1);
 			final ConstructionObject o = C.find(s);
-			if (o instanceof PrimitiveCircleObject)
-				return ((PrimitiveCircleObject) o).getP1().getName();
+			if (o instanceof PrimitiveCircleObject) {
+                            return ((PrimitiveCircleObject) o).getP1().getName();
+                        }
 		} else if (s.startsWith("a(") && s.endsWith(")")) {
 			s = s.substring(2, s.length() - 1);
 			final ConstructionObject o = C.find(s);
-			if (o instanceof TwoPointLineObject)
-				return ((TwoPointLineObject) o).getP1().getName();
+			if (o instanceof TwoPointLineObject) {
+                            return ((TwoPointLineObject) o).getP1().getName();
+                        }
 		} else if (s.startsWith("b(") && s.endsWith(")")) {
 			s = s.substring(2, s.length() - 1);
 			final ConstructionObject o = C.find(s);
-			if (o instanceof TwoPointLineObject)
-				return ((TwoPointLineObject) o).getP2().getName();
+			if (o instanceof TwoPointLineObject) {
+                            return ((TwoPointLineObject) o).getP2().getName();
+                        }
 		}
 		return s;
 	}
@@ -771,15 +796,16 @@ public class Interpreter {
 		new FunctionConstructor() };
 
 	static public String ONs[] = { "point", "segment", "line", "ray", "circle",
-		"intersection", "parallel", "plumb", "midpoint", "angle", "area",
-		"quadric", "expression", "function" };
+		"intersection", "parallel", "plumb", "angle", "area",
+		"quadric", "expression", "function","text" };
 
 	static public int findFunction(final String function, final ZirkelCanvas zc) {
 		for (int i = 0; i < OCs.length; i++) {
-			if (nametest(function, OCs[i].getTag()) && zc.enabled(ONs[i]))
-				return i;
+			if (nametest(function, OCs[i].getTag()) && zc.enabled(ONs[i])) {
+                            return i;
+                        }
 		}
 		return -1;
 	}
 
-}
+}
\ No newline at end of file
