@@ -1,5 +1,5 @@
-/* 
- 
+/*
+
 Copyright 2006 Rene Grothmann, modified by Eric Hakenholz
 
 This file is part of C.a.R. software.
@@ -15,16 +15,16 @@ This file is part of C.a.R. software.
 
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
- 
+
  */
- 
- 
+
+
  package rene.zirkel.expression;
 
 import java.util.Enumeration;
 
 import rene.util.MyVector;
-import rene.zirkel.Zirkel;
+import rene.gui.Global;
 import rene.zirkel.construction.Construction;
 import rene.zirkel.construction.ConstructionException;
 import rene.zirkel.construction.DepList;
@@ -39,6 +39,7 @@ import rene.zirkel.objects.PrimitiveLineObject;
 import rene.zirkel.objects.SimulationObject;
 import rene.zirkel.objects.TrackObject;
 import rene.zirkel.objects.UserFunctionObject;
+import rene.zirkel.objects.VectorObject;
 
 /*
  This file contains classes for computing arithmetic expression. Those
@@ -58,6 +59,7 @@ class ExpressionText {
 	String Var[];
 	boolean NoCircles;
 
+
 	public ExpressionText(final String S, final Construction c,
 			final ConstructionObject o, final DepList dl,
 			final boolean nocircles) {
@@ -188,7 +190,7 @@ class BasicExpression {
 		if (t.next() == ')') {
 			t.advance();
 		} else {
-			throw new ConstructionException(Zirkel.name("exception.bracket"));
+			throw new ConstructionException(Global.name("exception.bracket"));
 		}
 		return E;
 	}
@@ -241,8 +243,7 @@ class DoubleExpression extends BasicExpression {
 				Digit = true;
 			} else if (c == '.') {
 				if (Punkt) {
-					throw new ConstructionException(Zirkel
-							.name("exception.dot"));
+					throw new ConstructionException(Global.name("exception.dot"));
 				}
 				Punkt = true;
 				num += c;
@@ -266,7 +267,7 @@ class DoubleExpression extends BasicExpression {
 		}
 
 		if (!Digit) {
-			throw new ConstructionException(Zirkel.name("exception.nodigit"));
+			throw new ConstructionException(Global.name("exception.nodigit"));
 		}
 
 		return new DoubleExpression(Double.valueOf(num).doubleValue());
@@ -346,7 +347,7 @@ class FindObjectExpression extends ObjectExpression implements Translator {
 			t.advance();
 			final BasicExpression E = scan(t, true);
 			if (t.next() != '\"') {
-				throw new ConstructionException(Zirkel.name("exception.quotes"));
+				throw new ConstructionException(Global.name("exception.quotes"));
 			}
 			t.advance();
 			return E;
@@ -390,14 +391,14 @@ class FindObjectExpression extends ObjectExpression implements Translator {
 	/**
 	 * Used to translate expressions with @P in macros
 	 */
+	@Override
 	public void laterTranslate(final Construction from) {
 		if (C == null) {
 			return;
 		}
 		final ConstructionObject o = from.find(Name);
 		if (o == null || o.getTranslation() == null) {
-			from.addError(ConstructionObject.text1(Zirkel
-					.name("warning.macrodefinition"), Name));
+			from.addError(ConstructionObject.text1(Global.name("warning.macrodefinition"), Name));
 			return;
 		}
 		Name = o.getTranslation().getName();
@@ -444,7 +445,7 @@ class ObjectExpression extends BasicExpression {
 			t.advance();
 			final BasicExpression E = scan(t, true);
 			if (t.next() != '\"') {
-				throw new ConstructionException(Zirkel.name("exception.quotes"));
+				throw new ConstructionException(Global.name("exception.quotes"));
 			}
 			t.advance();
 			return E;
@@ -509,8 +510,7 @@ class ObjectExpression extends BasicExpression {
 				if (t.getConstruction().loading()) {
 					return new FindObjectExpression(s, t.getConstruction());
 				} else {
-					throw new ConstructionException(Zirkel
-							.name("exception.notfound")
+					throw new ConstructionException(Global.name("exception.notfound")
 							+ " (" + s + ")");
 				}
 			}
@@ -520,7 +520,7 @@ class ObjectExpression extends BasicExpression {
 			if (t.getConstruction().dependsOn(o, t.getObject())) {
 				if (t.nocircles()) {
 					throw new ConstructionException(ConstructionObject.text1(
-							Zirkel.name("exception.depends"), s));
+							Global.name("exception.depends"), s));
 				}
 				return new FindObjectExpression(s, t.getConstruction());
 			}
@@ -570,10 +570,10 @@ class ObjectExpression extends BasicExpression {
 
 /**
  * @author Rene
- * 
+ *
  *         Evaluates a user funktion (a FunctionObject). The Y-expression of
  *         this function is used.
- * 
+ *
  */
 class UserFunctionExpression extends BasicExpression {
 
@@ -648,8 +648,7 @@ class SimulationExpression extends BasicExpression {
 	@Override
 	public double getValue() throws ConstructionException {
 		if (C.BlockSimulation) {
-			throw new ConstructionException(Zirkel
-					.name("exception.simmulation.block"));
+			throw new ConstructionException(Global.name("exception.simmulation.block"));
 		}
 		try {
 			final double aa = E.getValue();
@@ -722,17 +721,37 @@ class FunctionExpression extends BasicExpression {
 		NParams = 3;
 	}
 
+    /**
+     * @author Vincent Robert, 2nde SI 3, LPO Roland-Garros
+     * pgcd de deux nombres
+     * @param x entier premier nombre
+     * @param y entier second nombre
+     * @return le pgcd
+     */
+    public int pgcd(int x, int y){
+        int a=Math.abs(x);
+        int b=Math.abs(y);
+        int c;
+        while(b>0){
+            c=a%b;
+            a=b;
+            b=c;
+        }
+        return a;
+    }
+
 	final static String Functions[] = { "sin", "cos", "tan", "arcsin",
 		"arccos", "arctan", "sqrt", "exp", "log", "round", "x", "y",
 		"floor", "ceil", "d", "a", "angle180", "angle360", "abs", "scale",
 		"sign", "d", "sum", "if", "deg", "rad", "integrate", "zero",
 		"diff", "min", "max", "length", "rsin", "rcos", "rtan", "rarcsin",
 		"rarccos", "rarctan", "sinhyp", "coshyp", "z", "simulate",
-		"inside", "random", "old" };
+		"inside", "random", "old", "ratan2", "atan2", "tanhyp", "Argsinh",
+                "Argcosh", "Argtanh", "div","mod", "gcd", "lcm", "x3D", "y3D", "z3D", "d3D"};
 	final static int NX = 10, NY = 11, ND = 14, NA = 15, NS = 19, NSUM = 22,
 	NIF = 23, NINT = 26, NZERO = 27, NDIFF = 28, NMIN = 29, NMAX = 30,
 	NLENGTH = 31, NZ = 40, NSIM = 41, NINSIDE = 42, NRANDOM = 43,
-	NOLD = 44;
+	NOLD = 44, NRATAN2=45, NATAN2=46, NDIV=51, NMOD=52, NGCD=53, NLCM=54, NX3D=55, NY3D=56, NZ3D= 57, ND3D=58 ;
 
 	public static BasicExpression scan(final ExpressionText t, final String name)
 	throws ConstructionException {
@@ -756,8 +775,7 @@ class FunctionExpression extends BasicExpression {
 					&& !(o == t.getObject())
 					&& !t.getConstruction().dependsOn(o, t.getObject())) {
 				if (t.next() != '(') {
-					throw new ConstructionException(Zirkel
-							.name("exception.parameter"));
+					throw new ConstructionException(Global.name("exception.parameter"));
 				}
 				t.advance();
 				final MyVector ex = new MyVector();
@@ -768,8 +786,7 @@ class FunctionExpression extends BasicExpression {
 						break;
 					}
 					if (t.next() != ',') {
-						throw new ConstructionException(Zirkel
-								.name("exception.parameter"));
+						throw new ConstructionException(Global.name("exception.parameter"));
 					}
 					t.advance();
 				}
@@ -782,11 +799,11 @@ class FunctionExpression extends BasicExpression {
 				ex.copyInto(exp);
 				return new UserFunctionExpression(o, exp);
 			}
-			throw new ConstructionException(Zirkel.name("exception.function")
+			throw new ConstructionException(Global.name("exception.function")
 					+ " (" + name + ")");
 		}
 		if (t.next() != '(') {
-			throw new ConstructionException(Zirkel.name("exception.parameter"));
+			throw new ConstructionException(Global.name("exception.parameter"));
 		}
 		t.advance();
 		BasicExpression e = TopExpression.scan(t);
@@ -801,11 +818,26 @@ class FunctionExpression extends BasicExpression {
 				e = new FunctionExpression(f, e);
 			} else {
 
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter")
+				throw new ConstructionException(Global.name("exception.parameter")
+						+ " (" + Functions[f] + ")");
+			}	
+		} 
+		else if (f == NX3D || f == NY3D || f == NZ3D) {
+			if (e instanceof FindObjectExpression) {
+				e = new FunctionExpression(f, e);
+			} else if (e instanceof ObjectExpression
+					&& ((ObjectExpression) e).getObject() instanceof PointObject) {
+				e = new FunctionExpression(f, e);
+			} else if (e instanceof ObjectExpression
+					&& ((ObjectExpression) e).getObject() instanceof PrimitiveLineObject) {
+				e = new FunctionExpression(f, e);
+			} else {
+
+				throw new ConstructionException(Global.name("exception.parameter")
 						+ " (" + Functions[f] + ")");
 			}
-		} else if (f == ND) {
+		} 
+		else if (f == ND) {
 			if (t.next() != ',') {
 				e = new DExpression(e);
 			} else {
@@ -817,12 +849,29 @@ class FunctionExpression extends BasicExpression {
 								.getObject() instanceof PointObject) || ee instanceof FindObjectExpression)) {
 					e = new FunctionExpression(f, e, ee);
 				} else {
-					throw new ConstructionException(Zirkel
-							.name("exception.parameter")
+					throw new ConstructionException(Global.name("exception.parameter")
 							+ " (" + Functions[f] + ")");
 				}
 			}
-		} else if (f == NOLD) {
+		} 
+		else if (f == ND3D) {
+			if (t.next() != ',') {
+				e = new D3DExpression(e);
+			} else {
+				t.advance();
+				final BasicExpression ee = TopExpression.scan(t);
+				if (((e instanceof ObjectExpression && ((ObjectExpression) e)
+						.getObject() instanceof PointObject) || e instanceof FindObjectExpression)
+						&& ((ee instanceof ObjectExpression && ((ObjectExpression) ee)
+								.getObject() instanceof PointObject) || ee instanceof FindObjectExpression)) {
+					e = new FunctionExpression(f, e, ee);
+				} else {
+					throw new ConstructionException(Global.name("exception.parameter")
+							+ " (" + Functions[f] + ")");
+				}
+			}
+		}
+		else if (f == NOLD) {
 			if (t.next() != ',') {
 				e = new OldExpression(e);
 			} else {
@@ -832,14 +881,12 @@ class FunctionExpression extends BasicExpression {
 			}
 		} else if (f == NA) {
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression ee = TopExpression.scan(t);
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression eee = TopExpression.scan(t);
@@ -851,21 +898,18 @@ class FunctionExpression extends BasicExpression {
 									.getObject() instanceof PointObject) || eee instanceof FindObjectExpression)) {
 				e = new FunctionExpression(f, e, ee, eee);
 			} else {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter")
+				throw new ConstructionException(Global.name("exception.parameter")
 						+ " (" + Functions[f] + ")");
 			}
 
 		} else if (f == NS) {
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression ee = TopExpression.scan(t);
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression eee = TopExpression.scan(t);
@@ -888,32 +932,30 @@ class FunctionExpression extends BasicExpression {
 			}
 		} else if (f == NIF) {
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression ee = TopExpression.scan(t);
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression eee = TopExpression.scan(t);
 			e = new IfExpression(e, ee, eee);
 		} else if (f == NINT || f == NZERO || f == NMIN || f == NMAX
-				|| f == NLENGTH) {
-			if (!(e instanceof ObjectExpression)) {
-				if (f == NMAX || f == NMIN) {
+				|| f == NLENGTH || f==NRATAN2 || f==NATAN2
+                                || f == NDIV || f== NMOD || f == NGCD || f == NLCM) {
+			if (!(e instanceof ObjectExpression)||t.isVar(e.toString())) {
+				if (f == NMAX || f == NMIN || f==NRATAN2 || f==NATAN2
+                                        || f == NDIV || f == NMOD || f == NGCD || f == NLCM) {
 					if (t.next() != ',') {
-						throw new ConstructionException(Zirkel
-								.name("exception.parameter"));
+						throw new ConstructionException(Global.name("exception.parameter"));
 					}
 					t.advance();
 					final BasicExpression ee = TopExpression.scan(t);
 					e = new FunctionExpression(f, e, ee);
 				} else {
-					throw new ConstructionException(Zirkel
-							.name("exception.parameter")
+					throw new ConstructionException(Global.name("exception.parameter")
 							+ " (" + Functions[f] + ")");
 				}
 			} else {
@@ -921,34 +963,31 @@ class FunctionExpression extends BasicExpression {
 				|| ((ObjectExpression) e).getObject() instanceof TrackObject;
 				if ((f == NINT || f == NLENGTH) && t.next() == ')') {
 					if (!function) {
-						throw new ConstructionException(Zirkel
-								.name("exception.parameter")
+						throw new ConstructionException(Global.name("exception.parameter")
 								+ " (" + Functions[f] + ")");
 					}
 					e = new FunctionExpression(f, e);
 				} else if (f == NLENGTH) {
-					throw new ConstructionException(Zirkel
-							.name("exception.parameter"));
+					throw new ConstructionException(Global.name("exception.parameter"));
 				} else {
 					if (t.next() != ',') {
-						throw new ConstructionException(Zirkel
-								.name("exception.parameter"));
+						throw new ConstructionException(Global.name("exception.parameter"));
 					}
 					t.advance();
 					final BasicExpression ee = TopExpression.scan(t);
 					if (function) {
 						if (t.next() != ',') {
-							throw new ConstructionException(Zirkel
-									.name("exception.parameter"));
+							throw new ConstructionException(Global.name("exception.parameter"));
 						}
 						t.advance();
 						final BasicExpression eee = TopExpression.scan(t);
 						e = new FunctionExpression(f, e, ee, eee);
-					} else if (f == NMIN || f == NMAX) {
+					} else if (f == NMIN || f == NMAX || f == NATAN2
+                                                || f == NRATAN2 || f == NDIV || f == NMOD
+                                                || f == NGCD || f == NLCM) {
 						e = new FunctionExpression(f, e, ee);
 					} else {
-						throw new ConstructionException(Zirkel
-								.name("exception.parameter")
+						throw new ConstructionException(Global.name("exception.parameter")
 								+ " (" + Functions[f] + ")");
 					}
 				}
@@ -956,27 +995,23 @@ class FunctionExpression extends BasicExpression {
 		} else if (f == NDIFF) {
 			if (!(e instanceof ObjectExpression)
 					|| !(((ObjectExpression) e).getObject() instanceof Evaluator)) {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter")
+				throw new ConstructionException(Global.name("exception.parameter")
 						+ " (" + Functions[f] + ")");
 			}
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression ee = TopExpression.scan(t);
 			e = new FunctionExpression(f, e, ee);
 		} else if (f == NSIM) {
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression ee = TopExpression.scan(t);
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression eee = TopExpression.scan(t);
@@ -986,23 +1021,20 @@ class FunctionExpression extends BasicExpression {
 				final ConstructionObject SO = ((ObjectExpression) e)
 				.getObject();
 				if (t.getConstruction().dependsOn(SO, t.getObject())) {
-					throw new ConstructionException(Zirkel
-							.name("exception.parameter")
+					throw new ConstructionException(Global.name("exception.parameter")
 							+ " (" + Functions[f] + ")");
 				}
 				e = new SimulationExpression(
 						((ObjectExpression) e).getObject(), t.getObject(), ee,
 						((ObjectExpression) eee).getObject());
 			} else {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter")
+				throw new ConstructionException(Global.name("exception.parameter")
 						+ " (" + Functions[f] + ")");
 			}
 
 		} else if (f == NINSIDE) {
 			if (t.next() != ',') {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter"));
+				throw new ConstructionException(Global.name("exception.parameter"));
 			}
 			t.advance();
 			final BasicExpression ee = TopExpression.scan(t);
@@ -1012,15 +1044,14 @@ class FunctionExpression extends BasicExpression {
 							.getObject() instanceof InsideObject) || ee instanceof FindObjectExpression)) {
 				e = new FunctionExpression(f, e, ee);
 			} else {
-				throw new ConstructionException(Zirkel
-						.name("exception.parameter")
+				throw new ConstructionException(Global.name("exception.parameter")
 						+ " (" + Functions[f] + ")");
 			}
 		} else {
 			e = new FunctionExpression(f, e);
 		}
 		if (t.next() != ')') {
-			throw new ConstructionException(Zirkel.name("exception.parameter"));
+			throw new ConstructionException(Global.name("exception.parameter"));
 		}
 		t.advance();
 		return e;
@@ -1037,27 +1068,46 @@ class FunctionExpression extends BasicExpression {
 		case NY:
 			cc = getPointLineY(0);
 			return cc;
+		case NX3D:
+			cc = getPointLineX3D(0);
+			return cc;
+		case NY3D:
+			cc = getPointLineY3D(0);
+			return cc;
+		case NZ3D:
+			cc = getPointLineZ3D(0);
+			return cc;
 		case NZ:
 			P = getPoint(0);
 			if (!P.valid()) {
-				throw new InvalidException(Zirkel.name("exception.invalid"));
+				throw new InvalidException(Global.name("exception.invalid"));
 			}
 			return P.getZ();
 		case ND:
 			P = getPoint(0);
 			PP = getPoint(1);
 			if (!P.valid() || !PP.valid()) {
-				throw new InvalidException(Zirkel.name("exception.invalid"));
+				throw new InvalidException(Global.name("exception.invalid"));
 			}
 			double dx = P.getX() - PP.getX();
 			double dy = P.getY() - PP.getY();
 			return Math.sqrt(dx * dx + dy * dy);
+		case ND3D:
+			P = getPoint(0);
+			PP = getPoint(1);
+			if (!P.valid() || !PP.valid()) {
+				throw new InvalidException(Global.name("exception.invalid"));
+			}
+			double dx3D = P.getX3D() - PP.getX3D();
+			double dy3D = P.getY3D() - PP.getY3D();
+			double dz3D = P.getZ3D() - PP.getZ3D();
+			return Math.sqrt(dx3D * dx3D + dy3D * dy3D + dz3D * dz3D);
 		case NA:
 			P = getPoint(0);
 			PP = getPoint(1);
 			PPP = getPoint(2);
 			if (!P.valid() || !PP.valid() || !PPP.valid()) {
-				throw new InvalidException(Zirkel.name("exception.invalid"));
+				throw new InvalidException(Global.name("exception.invalid"));
 			}
 			dx = P.getX() - PP.getX();
 			dy = P.getY() - PP.getY();
@@ -1077,7 +1127,7 @@ class FunctionExpression extends BasicExpression {
 			xa = E[1].getValue(),
 			xb = E[2].getValue();
 			if (x < xa || x >= xb || xb <= xa) {
-				throw new InvalidException(Zirkel.name("exception.invalid"));
+				throw new InvalidException(Global.name("exception.invalid"));
 			}
 			return (x - xa) / (xb - xa);
 		case NINT:
@@ -1213,6 +1263,51 @@ class FunctionExpression extends BasicExpression {
 			return (Math.exp(x) - Math.exp(-x)) / 2;
 		case 39:
 			return (Math.exp(x) + Math.exp(-x)) / 2;
+                case 47:
+                        return (Math.exp(x) - Math.exp(-x))/(Math.exp(x) + Math.exp(-x));
+                case 48:
+                        return Math.log(x+Math.sqrt(x*x+1));
+                case 49:
+                        return Math.log(x+Math.sqrt(x*x-1));
+                case 50:
+                        return Math.log((1+x)/(1-x))/2.0;
+                case 45://these two functions by S. Reyrolle
+                        if(NParams==2){
+                           return Math.atan2(x,E[1].getValue());
+                        } else{
+                           throw new ConstructionException(Global.name("exception.parameter"));
+                        }
+                case 46:
+                        if(NParams==2){
+                           return Math.atan2(x,E[1].getValue())/ Math.PI * 180;
+                        }else{
+                           throw new ConstructionException(Global.name("exception.parameter"));
+                        }
+                case NDIV:
+                        if(NParams==2){
+                            return Math.floor(x/E[1].getValue());
+                        }else{
+                            throw new ConstructionException(Global.name("exception.parameter"));
+                        }
+                case NMOD:
+                        if(NParams==2){
+                            return x%(E[1].getValue());
+                        } else {
+                            throw new ConstructionException(Global.name("exception.parameter"));
+                        }
+                case NGCD:
+                        if(NParams==2){
+                            return pgcd((int) x,(int) E[1].getValue());
+                        } else {
+                            throw new ConstructionException(Global.name("exception.parameter"));
+                        }
+                case NLCM:
+                        if(NParams==2){
+                            return x*E[1].getValue()/pgcd((int) x,(int) E[1].getValue());
+
+                        } else {
+                            throw new ConstructionException(Global.name("exception.parameter"));
+                        }
 		}
 		throw new ConstructionException("");
 	}
@@ -1220,6 +1315,7 @@ class FunctionExpression extends BasicExpression {
 	public double getPointLineX(final int n) throws ConstructionException {
 		PointObject p;
 		PrimitiveLineObject l;
+                VectorObject s;
 		try {
 			p = (PointObject) ((ObjectExpression) E[n]).getObject();
 			if (!p.valid()) {
@@ -1227,6 +1323,15 @@ class FunctionExpression extends BasicExpression {
 			}
 			return p.getX();
 		} catch (final Exception e) {
+                    try{
+                        s=(VectorObject) ((ObjectExpression) E[n]).getObject();
+                        if (!s.valid()){
+                            throw new ConstructionException("exception.invalid");
+                        }
+                        return s.getDeltaX();
+
+                        } catch (final Exception eee) {
+                    }
 			try {
 				l = (PrimitiveLineObject) ((ObjectExpression) E[n]).getObject();
 				if (!l.valid()) {
@@ -1242,6 +1347,7 @@ class FunctionExpression extends BasicExpression {
 	public double getPointLineY(final int n) throws ConstructionException {
 		PointObject p;
 		PrimitiveLineObject l;
+                VectorObject s;
 		try {
 			p = (PointObject) ((ObjectExpression) E[n]).getObject();
 			if (!p.valid()) {
@@ -1249,6 +1355,15 @@ class FunctionExpression extends BasicExpression {
 			}
 			return p.getY();
 		} catch (final Exception e) {
+                    try{
+                        s=(VectorObject) ((ObjectExpression) E[n]).getObject();
+                        if (!s.valid()){
+                            throw new ConstructionException("exception.invalid");
+                        }
+                        return s.getDeltaY();
+
+                        } catch (final Exception eee) {
+                    }
 			try {
 				l = (PrimitiveLineObject) ((ObjectExpression) E[n]).getObject();
 				if (!l.valid()) {
@@ -1260,7 +1375,103 @@ class FunctionExpression extends BasicExpression {
 			}
 		}
 	}
+	
+	public double getPointLineX3D(final int n) throws ConstructionException {
+		PointObject p;
+		PrimitiveLineObject l;
+                VectorObject s;
+		try {
+			p = (PointObject) ((ObjectExpression) E[n]).getObject();
+			if (!p.valid()) {
+				throw new ConstructionException("exception.invalid");
+			}
+			return p.getX3D();
+		} catch (final Exception e) {
+                    try{
+                        s=(VectorObject) ((ObjectExpression) E[n]).getObject();
+                        if (!s.valid()){
+                            throw new ConstructionException("exception.invalid");
+                        }
+                        return s.getDeltaX3D();
 
+                        } catch (final Exception eee) {
+                    }
+			try {
+				l = (PrimitiveLineObject) ((ObjectExpression) E[n]).getObject();
+				if (!l.valid()) {
+					throw new ConstructionException("exception.invalid");
+				}
+				return l.getDX3D();
+			} catch (final Exception ee) {
+				throw new ConstructionException("exception.notfound");
+			}
+		}
+	}
+	
+	public double getPointLineY3D(final int n) throws ConstructionException {
+		PointObject p;
+		PrimitiveLineObject l;
+                VectorObject s;
+		try {
+			p = (PointObject) ((ObjectExpression) E[n]).getObject();
+			if (!p.valid()) {
+				throw new ConstructionException("exception.invalid");
+			}
+			return p.getY3D();
+		} catch (final Exception e) {
+                    try{
+                        s=(VectorObject) ((ObjectExpression) E[n]).getObject();
+                        if (!s.valid()){
+                            throw new ConstructionException("exception.invalid");
+                        }
+                        return s.getDeltaY3D();
+
+                        } catch (final Exception eee) {
+                    }
+			try {
+				l = (PrimitiveLineObject) ((ObjectExpression) E[n]).getObject();
+				if (!l.valid()) {
+					throw new ConstructionException("exception.invalid");
+				}
+				return l.getDY3D();
+			} catch (final Exception ee) {
+				throw new ConstructionException("exception.notfound");
+			}
+		}
+	}
+	
+	public double getPointLineZ3D(final int n) throws ConstructionException {
+		PointObject p;
+		PrimitiveLineObject l;
+                VectorObject s;
+		try {
+			p = (PointObject) ((ObjectExpression) E[n]).getObject();
+			if (!p.valid()) {
+				throw new ConstructionException("exception.invalid");
+			}
+			return p.getZ3D();
+		} catch (final Exception e) {
+                    try{
+                        s=(VectorObject) ((ObjectExpression) E[n]).getObject();
+                        if (!s.valid()){
+                            throw new ConstructionException("exception.invalid");
+                        }
+                        return s.getDeltaZ3D();
+
+                        } catch (final Exception eee) {
+                    }
+			try {
+				l = (PrimitiveLineObject) ((ObjectExpression) E[n]).getObject();
+				if (!l.valid()) {
+					throw new ConstructionException("exception.invalid");
+				}
+				return l.getDZ3D();
+			} catch (final Exception ee) {
+				throw new ConstructionException("exception.notfound");
+			}
+		}
+	}
+	
 	public PointObject getPoint(final int n) throws ConstructionException {
 		PointObject p;
 		try {
@@ -1350,7 +1561,7 @@ class DExpression extends FunctionExpression {
 	public DExpression(final BasicExpression e) {
 		super(21, e);
 	}
-
+	
 	@Override
 	public double getValue() throws ConstructionException {
 		if (E[0] instanceof ObjectExpression) {
@@ -1410,6 +1621,77 @@ class DExpression extends FunctionExpression {
 	}
 }
 
+class D3DExpression extends FunctionExpression {
+	
+	double Old = 0;
+	double Old1 = 0;
+	double Old2 = 0;
+	boolean start = false;
+
+	public D3DExpression(final BasicExpression e) {
+		super(58, e);
+	}
+	
+	@Override
+	public double getValue() throws ConstructionException {
+		if (E[0] instanceof ObjectExpression) {
+			final ConstructionObject o = ((ObjectExpression) E[0]).getObject();
+			if (o instanceof PointObject) {
+				final PointObject p = (PointObject) o;
+				if (p.dontUpdate()) {
+					return 0;
+				}
+				final double x3D = p.getX3D(), y3D = p.getY3D(), z3D = p.getZ3D();
+				if (start) {
+					final double res = (x3D - Old) * (x3D - Old) + (y3D - Old1) * (y3D - Old1) + (z3D - Old2) * (z3D - Old2);
+					Old = x3D;
+					Old1 = y3D;
+					Old2 = y3D;
+					return Math.sqrt(res);
+				}
+				Old = x3D;
+				Old1 = y3D;
+				Old2 = z3D;
+				start = true;
+				return 0;
+			} else if (o instanceof AngleObject) {
+				final AngleObject a = (AngleObject) o;
+				final double x = a.getValue();
+				if (start) {
+					double res = x - Old;
+					if (res < -180) {
+						res += 180;
+					}
+					if (res > 180) {
+						res -= 180;
+					}
+					Old = x;
+					return res;
+				}
+				Old = x;
+				start = true;
+				return 0;
+			}
+		}
+		final double x = E[0].getValue();
+		double res;
+		if (start) {
+			res = x - Old;
+		} else {
+			res = 0;
+			start = true;
+		}
+		Old = x;
+		return res;
+	}
+
+	@Override
+	public void reset() {
+		start = false;
+		super.reset();
+	}
+}
+
 class CumSumExpression extends FunctionExpression {
 
 	double sum = 0;
@@ -1695,7 +1977,7 @@ abstract class ElementaryExpression extends BasicExpression {
 			throw e;
 		} catch (final Exception e) {
 		}
-		throw new ConstructionException(Zirkel.name("exception.elementary"));
+		throw new ConstructionException(Global.name("exception.elementary"));
 	}
 
 	@Override
@@ -2311,14 +2593,18 @@ class OrExpression extends BasicExpression {
 	}
 
 	@Override
+	//suppression de l'évaluation paresseuse par Patrice pour un ExecuteMacro Expression-compatible
 	public double getValue() throws ConstructionException {
-		if (E1.getValue() != 0.0 || E2.getValue() != 0.0) {
-			return 1.0;
-		} else {
-			return 0.0;
-		}
-	}
-
+		try {
+			if (E1.getValue() == 1.0) return 1.0;
+		} catch (Exception e) {}
+		try {
+			if (E2.getValue() == 1.0) return 1.0;
+		} catch (Exception e) {}
+		if (E1.getValue() != 1.0 && E2.getValue() != 1.0) {return 0.0;} else {return 1.0;}
+	
+                }
+	
 	@Override
 	public void translate() {
 		E1.translate();
@@ -2363,7 +2649,7 @@ public class Expression {
 
 	/**
 	 * Create a new expression
-	 * 
+	 *
 	 * @param s
 	 *            expression string
 	 * @param c
@@ -2389,8 +2675,7 @@ public class Expression {
 			t.setVar(var);
 			E = TopExpression.scan(t);
 			if (t.next() != 0) {
-				throw new ConstructionException(Zirkel
-						.name("exception.superfluous"));
+				throw new ConstructionException(Global.name("exception.superfluous"));
 			}
 			Valid = true;
 		} catch (final Exception e) {
@@ -2423,11 +2708,11 @@ public class Expression {
 			return Value;
 		}
 		if (!Valid) {
-			throw new ConstructionException(Zirkel.name("exception.expression"));
+			throw new ConstructionException(Global.name("exception.expression"));
 		}
 		final double x = E.getValue();
 		if (Double.isNaN(x) || Double.isInfinite(x)) {
-			throw new ConstructionException(Zirkel.name("exception.value"));
+			throw new ConstructionException(Global.name("exception.value"));
 		}
 		return x;
 	}
