@@ -49,9 +49,15 @@ public class Macro extends Construction implements Cloneable {
 	public String PromptName[] = new String[0];
 	public String LastParams[];
 	public boolean Fixed[];
+//        public boolean createDPLineObjects=false;
 	boolean Protected = false;
 	boolean HideDuplicates = true;
 
+// Macro renvoyant un dp_mode (voir la classe ConstructionObject).
+// 0 pour un objet non-DP, sinon 
+// ConstructionObject.DP_LINE ou ConstructionObject.DP_SEGMENT :
+        public int createDPObjects=0;
+
 	/**
 	 * @param zc
 	 *            The ZirkelCanvas.
@@ -220,7 +226,7 @@ public class Macro extends Construction implements Cloneable {
 			// Read the objects, the comment
 			if (tag.name().equals("Objects")) // Objects
 			{
-				readConstruction(t);
+				readConstruction(t, false);
 				break;
 			} else if (tag.name().equals("Comment")) // Comment
 			{
