@@ -21,6 +21,7 @@ This file is part of C.a.R. software.
  
  package rene.zirkel.objects;
 
+import eric.bar.JPropertiesBar;
 import java.awt.Button;
 import java.awt.Checkbox;
 import java.awt.Color;
@@ -29,7 +30,7 @@ import java.awt.TextField;
 import java.awt.event.FocusEvent;
 import java.util.Enumeration;
 
-import javax.swing.JPanel;
+import eric.JEricPanel;
 
 import rene.dialogs.Warning;
 import rene.gui.ButtonAction;
@@ -38,119 +39,20 @@ import rene.gui.IconBar;
 import rene.gui.MyLabel;
 import rene.gui.TextFieldAction;
 import rene.util.xml.XmlWriter;
-import rene.zirkel.Zirkel;
+import rene.gui.Global;
 import rene.zirkel.ZirkelCanvas;
 import rene.zirkel.construction.Construction;
 import rene.zirkel.construction.ConstructionException;
 import rene.zirkel.construction.Count;
-import rene.zirkel.dialogs.EditConditionals;
-import rene.zirkel.dialogs.ObjectEditDialog;
 import rene.zirkel.expression.Expression;
+import rene.zirkel.expression.ExpressionColor;
 import rene.zirkel.expression.InvalidException;
 import rene.zirkel.graphics.MyGraphics;
-import rene.zirkel.graphics.MyGraphics13;
-import eric.JGlobals;
+import rene.zirkel.graphics.MainGraphics;
 
-class FixedAngleEditDialog extends ObjectEditDialog {
 
-	/**
-	 * 
-	 */
-	private static final long serialVersionUID = 1L;
-	TextField Length;
-	Checkbox Fixed;
-	IconBar SizeIB;
-	ZirkelCanvas ZC;
-	Button SetButton;
 
-	public FixedAngleEditDialog(final Frame f, final FixedAngleObject o,
-			final ZirkelCanvas zc) {
-		super(f, Zirkel.name("edit.angle.title"), o, "fixedangle");
-		ZC = zc;
-	}
 
-	@Override
-	public void addFirst(final JPanel P) {
-		final FixedAngleObject o = (FixedAngleObject) O;
-		Length = new TextFieldAction(this, "Length", o.getE());
-		P.add(new MyLabel(Zirkel.name("edit.angle.length")));
-		P.add(Length);
-		Fixed = new Checkbox("");
-		Fixed.setState(!o.isDragable());
-		P.add(new MyLabel(Zirkel.name("edit.fixed")));
-		P.add(Fixed);
-	}
-
-	@Override
-	public void doAction(final String o) {
-		if (o.equals("Length") && Fixed != null) {
-			Fixed.setState(true);
-			super.doAction("OK");
-		} else if (o.equals("Set")) {
-			ZC.set((FixedAngleObject) O);
-			super.doAction("OK");
-		} else {
-			super.doAction(o);
-		}
-	}
-
-	@Override
-	public void addSecond(final JPanel P) {
-		final FixedAngleObject p = (FixedAngleObject) O;
-		SizeIB = new IconBar(F);
-		SizeIB.addToggleGroupLeft("angle", 5);
-		SizeIB.toggle("angle", p.getDisplaySize());
-		SizeIB.addOnOffLeft("filled");
-		SizeIB.setState("filled", p.isFilled());
-		SizeIB.addOnOffLeft("obtuse");
-		SizeIB.setState("obtuse", p.getObtuse());
-		SizeIB.addOnOffLeft("inverse");
-		SizeIB.setState("inverse", p.getInverse());
-		SizeIB.addOnOffLeft("anglereduce");
-		SizeIB.setState("anglereduce", p.isReduced());
-		P.add(new MyLabel(""));
-		P.add(SizeIB);
-		SizeIB.setIconBarListener(this);
-	}
-
-	@Override
-	public void addButton(final JPanel P) {
-		SetButton = new ButtonAction(this, Zirkel.name("edit.fixedangle.set"),
-		"Set");
-		P.add(SetButton);
-	}
-
-	@Override
-	public void iconPressed(final String o) {
-		if (o.equals("filled")) {
-			if (SizeIB.getState("filled")) {
-				IB.setState("isback", true);
-			}
-		}
-		super.iconPressed(o);
-	}
-
-	@Override
-	public void setAction() {
-		final FixedAngleObject o = (FixedAngleObject) O;
-		o.setObtuse(SizeIB.getState("obtuse"));
-		o.setInverse(SizeIB.getState("inverse"));
-		o.setReduced(SizeIB.getState("anglereduce"));
-		o.setEditFixed(Length.getText());
-		o.setDisplaySize(SizeIB.getToggleState("angle"));
-		o.setFilled(SizeIB.getState("filled"));
-		o.setDragable(!Fixed.getState());
-	}
-
-	@Override
-	public void focusGained(final FocusEvent e) {
-		if (Fixed != null && Fixed.getState()) {
-			Length.requestFocus();
-		} else {
-			super.focusGained(e);
-		}
-	}
-}
 
 public class FixedAngleObject extends PrimitiveLineObject implements
 MoveableObject, SimulationObject, InsideObject {
@@ -182,7 +84,7 @@ MoveableObject, SimulationObject, InsideObject {
 		setShowName(Global.getParameter("options.angle.shownames", false));
 		setShowValue(Global.getParameter("options.angle.showvalues", false));
 		setColor(Global.getParameter("options.angle.color", 0), Global
-				.getParameter("options.angle.pcolor", (Color) null));
+				.getParameter("options.angle.pcolor", (ExpressionColor) null, this));
 		setColorType(Global.getParameter("options.angle.colortype", 0));
 		setFilled(Global.getParameter("options.angle.filled", false));
 		setHidden(Cn.Hidden);
@@ -198,7 +100,7 @@ MoveableObject, SimulationObject, InsideObject {
 		setShowName(Global.getParameter("options.angle.shownames", false));
 		setShowValue(Global.getParameter("options.angle.showvalues", false));
 		setColor(Global.getParameter("options.angle.color", 0), Global
-				.getParameter("options.angle.pcolor", (Color) null));
+				.getParameter("options.angle.pcolor", (ExpressionColor) null, this));
 		setColorType(Global.getParameter("options.angle.colortype", 0));
 		setFilled(Global.getParameter("options.angle.filled", false));
 		setObtuse(Global.getParameter("options.angle.obtuse", false));
@@ -288,8 +190,8 @@ MoveableObject, SimulationObject, InsideObject {
 		} else if (DA >= 360) {
 			DA -= 360;
 		}
-		if (isStrongSelected() && g instanceof MyGraphics13) {
-			((MyGraphics13) g).drawMarkerArc(c1 + R, r1 + R, R, A1 / Math.PI
+		if (isStrongSelected() && g instanceof MainGraphics) {
+			((MainGraphics) g).drawMarkerArc(c1 + R, r1 + R, R, A1 / Math.PI
 					* 180, DA);
 		}
 		g.setColor(this);
@@ -402,7 +304,7 @@ MoveableObject, SimulationObject, InsideObject {
 	}
 
 	double getDisplaySize(final ZirkelCanvas zc) {
-		double R = zc.dx((int) (12 * zc.pointSize()));
+		double R = zc.dx(12 * zc.pointSize());
 		if (DisplaySize == SMALL || DisplaySize == RECT) {
 			R /= 2;
 		} else if (DisplaySize == LARGER) {
@@ -429,13 +331,13 @@ MoveableObject, SimulationObject, InsideObject {
 		if (E == null || !E.isValid()) {
 			return;
 		}
-		setText(text3(Zirkel.name("text.fixedangle"), P1.getName(), P2
+		setText(text3(Global.name("text.fixedangle"), P1.getName(), P2
 				.getName(), E.toString()));
 	}
 
 	@Override
 	public String getDisplayValue() {
-		return JGlobals.getLocaleNumber(A / Math.PI * 180, "angles");
+		return Global.getLocaleNumber(A / Math.PI * 180, "angles");
 	}
 
 	// public String getDisplayValue() {
@@ -575,36 +477,7 @@ MoveableObject, SimulationObject, InsideObject {
 		super.printArgs(xml);
 	}
 
-	@Override
-	public void edit(final ZirkelCanvas zc) {
-		ObjectEditDialog d;
-		if (!rene.zirkel.Zirkel.IsApplet) {
-			eric.JGlobals.EditObject(this);
-			return;
-		}
-		while (true) {
-			d = new FixedAngleEditDialog(zc.getFrame(), this, zc);
-			d.setVisible(true);
-			zc.repaint();
-			EditAborted = false;
-			if (d.isAborted()) {
-				EditAborted = true;
-				break;
-			} else if (E != null && !E.isValid()) {
-				final Frame F = zc.getFrame();
-				final Warning w = new Warning(F, E.getErrorText(), Zirkel
-						.name("warning"), true);
-				w.center(F);
-				w.setVisible(true);
-			} else {
-				break;
-			}
-		}
-		if (d.wantsMore()) {
-			new EditConditionals(zc.getFrame(), this);
-			validate();
-		}
-	}
+
 
 	@Override
 	public boolean nearto(final int c, final int r, final ZirkelCanvas zc) {
@@ -625,7 +498,7 @@ MoveableObject, SimulationObject, InsideObject {
 			return true;
 		}
 		final double dx = zc.x(c) - X1, dy = zc.y(r) - Y1;
-		final double size = zc.dx((int) zc.selectionSize());
+		final double size = zc.dx(zc.selectionSize());
 		final double rd = getDisplaySize(zc);
 		final double rr = Math.sqrt(dx * dx + dy * dy);
 		boolean near;
@@ -882,4 +755,10 @@ MoveableObject, SimulationObject, InsideObject {
 		P.move(xmin, ymin);
 		return false;
 	}
+	public PointObject getP1() {
+		return P1;
+	}
+	public PointObject getP2() {
+		return P2;
+	}
 }
