@@ -1,5 +1,5 @@
-/* 
- 
+/*
+
 Copyright 2006 Rene Grothmann, modified by Eric Hakenholz
 
 This file is part of C.a.R. software.
@@ -15,311 +15,168 @@ This file is part of C.a.R. software.
 
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
- 
+
  */
- 
- 
+
+
  package rene.zirkel.objects;
 
 // file: Functionbject.java
-import java.awt.Checkbox;
-import java.awt.Color;
-import java.awt.Frame;
-import java.awt.TextField;
-import java.awt.event.FocusEvent;
 import java.util.Enumeration;
 import java.util.StringTokenizer;
 import java.util.Vector;
-
-import javax.swing.JPanel;
-
-import rene.dialogs.Warning;
-import rene.gui.ButtonAction;
 import rene.gui.Global;
-import rene.gui.IconBar;
-import rene.gui.MyLabel;
-import rene.gui.TextFieldAction;
 import rene.util.xml.XmlWriter;
-import rene.zirkel.Zirkel;
 import rene.zirkel.ZirkelCanvas;
 import rene.zirkel.construction.Construction;
 import rene.zirkel.construction.ConstructionException;
-import rene.zirkel.dialogs.EditConditionals;
-import rene.zirkel.dialogs.ObjectEditDialog;
 import rene.zirkel.expression.Expression;
+import rene.zirkel.expression.ExpressionColor;
 import rene.zirkel.expression.InvalidException;
 import rene.zirkel.graphics.FunctionPolygonFiller;
 import rene.zirkel.graphics.MyGraphics;
 import rene.zirkel.graphics.PolygonDrawer;
 import rene.zirkel.structures.Coordinates;
 
-class CurveEditDialog extends ObjectEditDialog {
-
-	/**
-	 * 
-	 */
-	private static final long serialVersionUID = 1L;
-	TextField VarMin, VarMax, DVar, Var, EX, EY;
-	IconBar IC, TypeIB;
-	ZirkelCanvas ZC;
-	Checkbox Special;
-
-	public CurveEditDialog(final ZirkelCanvas zc, final FunctionObject o) {
-		super(zc.getFrame(), Zirkel.name("edit.function.title"), o, "function");
-		ZC = zc;
-	}
-
-	@Override
-	public void addFirst(final JPanel P) {
-		final FunctionObject f = (FunctionObject) O;
-
-		VarMin = new TextFieldAction(this, "varmin", "" + f.VarMin, 30);
-		P.add(new MyLabel(Zirkel.name("function.varmin")));
-		P.add(VarMin);
-		VarMax = new TextFieldAction(this, "varmax", "" + f.VarMax, 30);
-		P.add(new MyLabel(Zirkel.name("function.varmax")));
-		P.add(VarMax);
-		DVar = new TextFieldAction(this, "dvar", "" + f.DVar, 30);
-		P.add(new MyLabel(Zirkel.name("function.dvar")));
-		P.add(DVar);
-
-		Var = new TextFieldAction(this, "var", "" + f.getVar(), 30);
-		P.add(new MyLabel(Zirkel.name("function.var")));
-		P.add(Var);
-		String ex = f.getEX();
-		if (ex.equals(f.Var)) {
-			ex = "";
-		}
-		EX = new TextFieldAction(this, "ex", "" + ex, 30);
-		P.add(new MyLabel(Zirkel.name("function.x")));
-		P.add(EX);
-		EY = new TextFieldAction(this, "ey", "" + f.getEY(), 30);
-		P.add(new MyLabel(Zirkel.name("function.y")));
-		P.add(EY);
-
-	}
-
-	@Override
-	public void addSecond(final JPanel P) {
-		final FunctionObject Func = (FunctionObject) O;
-
-		IC = new IconBar(F);
-		IC.setIconBarListener(this);
-		IC.addOnOffLeft("filled");
-		IC.setState("filled", Func.isFilled());
-		IC.setIconBarListener(this);
-		P.add(new MyLabel(""));
-		P.add(IC);
-
-		TypeIB = new IconBar(F);
-		TypeIB.addToggleGroupLeft("type", 6);
-		TypeIB.toggle("type", Func.getType());
-		P.add(new MyLabel(""));
-		P.add(TypeIB);
-
-		P.add(new MyLabel(Zirkel.name("edit.discrete")));
-		P.add(Special = new Checkbox());
-		Special.setState(Func.isSpecial());
-	}
-
-	@Override
-	public void addButton(final JPanel P) {
-		final FunctionObject f = (FunctionObject) O;
-		if (!f.Var.equals(f.EX)) {
-			if (f.Center == null) {
-				P.add(new ButtonAction(this, Zirkel
-						.name("edit.function.center"), "SetCenter"));
-			} else {
-				P.add(new ButtonAction(this, Zirkel.name("edit.function.free"),
-				"SetFree"));
-			}
-			P.add(new MyLabel(" "));
-		}
-	}
-
-	@Override
-	public void iconPressed(final String o) {
-		if (o.equals("filled")) {
-			if (IC.getState("filled")) {
-				IB.setState("isback", true);
-				ThicknessIB.setEnabled("solid", true);
-			} else {
-				IB.setState("isback", false);
-				ThicknessIB.setState("solid", false);
-				ThicknessIB.setEnabled("solid", false);
-			}
-		}
-		super.iconPressed(o);
-	}
-
-	@Override
-	public void setAction() {
-		final FunctionObject f = (FunctionObject) O;
-		f.setExpressions(Var.getText(), EX.getText(), EY.getText());
-		f.setRange(VarMin.getText(), VarMax.getText(), DVar.getText());
-		f.setFilled(IC.getState("filled"));
-		f.setType(TypeIB.getToggleState("type"));
-		f.setSpecial(Special.getState());
-	}
-
-	@Override
-	public void doAction(final String o) {
-		if (o.equals("SetCenter")) {
-			ZC.setCurveCenter((FunctionObject) O);
-			super.doAction("OK");
-		} else if (o.equals("SetFree")) {
-			((FunctionObject) O).Center = null;
-			super.doAction("OK");
-		} else {
-			super.doAction(o);
-		}
-	}
-
-	@Override
-	public void focusGained(final FocusEvent e) {
-		VarMin.requestFocus();
-	}
-}
 
 /**
  * @author Rene
- * 
+ *
  *         Function objects are parametric or cartesian curves. For parametric
  *         functions, depending on a parameter t , x(t) and y(t) are computed
  *         and drawn on the screen. For cartesian functions, the parameter x
  *         will be used.
- * 
+ *
  */
 public class FunctionObject extends ConstructionObject implements
 PointonObject, HeavyObject, DriverObject, Evaluator {
 
-	Expression EX = null, EY = null;
-	public Expression VarMin = null, VarMax = null, DVar = null;
-	String LASTEX = "", LASTEY = "", LASTVarMin = "", LASTVarMax = "",
-	LASTDVar = "";
-	double X[] = { 0 };
-	public String Var[] = { "x" };
-	boolean Filled = false;
-	Expression Center = null;
-	protected int Type = 0;
-	public final static int SQUARE = 0, DIAMOND = 1, CIRCLE = 2, DOT = 3,
-	CROSS = 4, DCROSS = 5;
-	protected boolean Special = false;
-	// Vector RefreshList=new Vector();
-	public Vector V = new Vector();
-	double cx, cy, ww, wh;
-	// this is a main object list which tells if the object needs to recompute :
-	Vector DriverObjectList = new Vector();
-	double c0, r0, c, r;
+    Expression EX = null, EY = null;
+    public Expression VarMin = null, VarMax = null, DVar = null;
+    String LASTEX = "", LASTEY = "", LASTVarMin = "", LASTVarMax = "", LASTDVar = "";
+    double X[] = { 0 };
+    public String Var[] = { "x" };
+    boolean Filled = false;
+    Expression Center = null;
+    protected int Type = 0;
+    public final static int SQUARE = 0, DIAMOND = 1, CIRCLE = 2, DOT = 3,
+    CROSS = 4, DCROSS = 5;
+    protected boolean Special = false;
+    // Vector RefreshList=new Vector();
+    public Vector V = new Vector();
+    double cx, cy, ww, wh;
+    // this is a main object list which tells if the object needs to recompute :
+    Vector DriverObjectList = new Vector();
+    double c0, r0, c, r;
+    private boolean isMinClosed, isMinOpen, isMaxClosed, isMaxOpen;
 
-	/**
-	 * Functions are HeavyObjects which means we always must see if it really
-	 * neads to recompute. Computing a function can be time consuming, but once
-	 * it's computed, the paint method is fast enough.
-	 * 
-	 * @param c
-	 */
-	public FunctionObject(final Construction c) {
-		super(c);
-		VarMin = new Expression("windowcx-windoww", c, this);
-		VarMax = new Expression("windowcx+windoww", c, this);
-		DVar = new Expression("0", c, this);
-		validate();
-		updateText();
-		cx = c.getX();
-		cy = c.getY();
-		ww = c.getW();
-		wh = c.getH();
-		Type = CROSS;
+    /**
+     * Functions are HeavyObjects which means we always must see if it really
+     * neads to recompute. Computing a function can be time consuming, but once
+     * it's computed, the paint method is fast enough.
+     *
+     * @param c
+     */
+    public FunctionObject(final Construction c) {
+    	super(c);
+	VarMin = new Expression("windowcx-windoww", c, this);
+	VarMax = new Expression("windowcx+windoww", c, this);
+	DVar = new Expression("0", c, this);
+	validate();
+	updateText();
+	cx = c.getX();
+	cy = c.getY();
+	ww = c.getW();
+	wh = c.getH();
+	Type = CROSS;
+    }
 
+    @Override
+    public void setDefaults() {
+	setShowName(Global.getParameter("options.locus.shownames", false));
+	setShowValue(Global.getParameter("options.locus.showvalues", false));
+//		setColor(Global.getParameter("options.locus.color", 0), Global
+//				.getParameter("options.locus.pcolor", (Color) null));
+        setColor(Global.getParameter("options.locus.color", 0));
+	setColorType(Global.getParameter("options.locus.colortype", 0));
+	setFilled(Global.getParameter("options.locus.filled", false));
+	setHidden(Cn.Hidden);
+	setObtuse(Cn.Obtuse);
+	setSolid(Cn.Solid);
+	setLarge(Cn.LargeFont);
+	setBold(Cn.BoldFont);
+    }
+
+    @Override
+    public void setTargetDefaults() {
+	setShowName(Global.getParameter("options.locus.shownames", false));
+	setShowValue(Global.getParameter("options.locus.showvalues", false));
+	setColor(Global.getParameter("options.locus.color", 0), Global.getParameter("options.locus.pcolor", (ExpressionColor) null, this));
+	setColorType(Global.getParameter("options.locus.colortype", 0));
+	setFilled(Global.getParameter("options.locus.filled", false));
+	setHidden(Cn.Hidden);
+	setObtuse(Cn.Obtuse);
+	setSolid(Cn.Solid);
+	setLarge(Cn.LargeFont);
+	setBold(Cn.BoldFont);
+    }
+
+    /**
+     * In order to see if the function must be recomputed or not, we have to
+     * register, in the DriverObjectList, all objects the function depends on.
+     * There are many possibilities for an object to be in this list : if it's
+     * used in the def of the function, if it's in the min or max text box,
+     * etc...
+     *
+     * @param c
+     */
+    @Override
+    public void searchDependencies(final Construction c) {
+	DriverObjectList.clear();
+	if (RekValidating) {
+	    return;
+	} // should not happen!
+	RekValidating = true;
+	Enumeration e = c.elements();
+	while (e.hasMoreElements()) {
+	    ((ConstructionObject) e.nextElement()).setRekFlag(false);
+	}
+	final ConstructionObject oEX[] = EX.getDepList().getArray();
+	final ConstructionObject oEY[] = EY.getDepList().getArray();
+	final ConstructionObject oVarMin[] = VarMin.getDepList().getArray();
+	final ConstructionObject oVarMax[] = VarMax.getDepList().getArray();
+	final ConstructionObject oDVar[] = DVar.getDepList().getArray();
+
+	for (final ConstructionObject element : oEX) {
+	    recursiveSearchDependencies((ConstructionObject) element);
+	}
+	for (final ConstructionObject element : oEY) {
+	    recursiveSearchDependencies((ConstructionObject) element);
+	}
+	for (final ConstructionObject element : oVarMin) {
+	    recursiveSearchDependencies((ConstructionObject) element);
+	}
+	for (final ConstructionObject element : oVarMax) {
+	    recursiveSearchDependencies((ConstructionObject) element);
+	}
+	for (final ConstructionObject element : oDVar) {
+	    recursiveSearchDependencies((ConstructionObject) element);
 	}
 
-	@Override
-	public void setDefaults() {
-		setShowName(Global.getParameter("options.locus.shownames", false));
-		setShowValue(Global.getParameter("options.locus.showvalues", false));
-		setColor(Global.getParameter("options.locus.color", 0), Global
-				.getParameter("options.locus.pcolor", (Color) null));
-		setColorType(Global.getParameter("options.locus.colortype", 0));
-		setFilled(Global.getParameter("options.locus.filled", false));
-		setHidden(Cn.Hidden);
-		setObtuse(Cn.Obtuse);
-		setSolid(Cn.Solid);
-		setLarge(Cn.LargeFont);
-		setBold(Cn.BoldFont);
-
-	}
-
-	@Override
-	public void setTargetDefaults() {
-		setShowName(Global.getParameter("options.locus.shownames", false));
-		setShowValue(Global.getParameter("options.locus.showvalues", false));
-		setColor(Global.getParameter("options.locus.color", 0), Global
-				.getParameter("options.locus.pcolor", (Color) null));
-		setColorType(Global.getParameter("options.locus.colortype", 0));
-		setFilled(Global.getParameter("options.locus.filled", false));
-		setHidden(Cn.Hidden);
-		setObtuse(Cn.Obtuse);
-		setSolid(Cn.Solid);
-		setLarge(Cn.LargeFont);
-		setBold(Cn.BoldFont);
-	}
-
-	/**
-	 * In order to see if the function must be recomputed or not, we have to
-	 * register, in the DriverObjectList, all objects the function depends on.
-	 * There are many possibilities for an object to be in this list : if it's
-	 * used in the def of the function, if it's in the min or max text box,
-	 * etc...
-	 * 
-	 * @param c
-	 */
-	public void searchDependencies(final Construction c) {
-		DriverObjectList.clear();
-		if (RekValidating) {
-			return;
-		} // should not happen!
-		RekValidating = true;
-		Enumeration e = c.elements();
-		while (e.hasMoreElements()) {
-			((ConstructionObject) e.nextElement()).setRekFlag(false);
-		}
-		final ConstructionObject oEX[] = EX.getDepList().getArray();
-		final ConstructionObject oEY[] = EY.getDepList().getArray();
-		final ConstructionObject oVarMin[] = VarMin.getDepList().getArray();
-		final ConstructionObject oVarMax[] = VarMax.getDepList().getArray();
-		final ConstructionObject oDVar[] = DVar.getDepList().getArray();
-
-		for (final ConstructionObject element : oEX) {
-			recursiveSearchDependencies((ConstructionObject) element);
-		}
-		for (final ConstructionObject element : oEY) {
-			recursiveSearchDependencies((ConstructionObject) element);
-		}
-		for (final ConstructionObject element : oVarMin) {
-			recursiveSearchDependencies((ConstructionObject) element);
-		}
-		for (final ConstructionObject element : oVarMax) {
-			recursiveSearchDependencies((ConstructionObject) element);
-		}
-		for (final ConstructionObject element : oDVar) {
-			recursiveSearchDependencies((ConstructionObject) element);
-		}
-
-		e = c.elements();
-		while (e.hasMoreElements()) {
-			final ConstructionObject oc = (ConstructionObject) e.nextElement();
-			if ((oc.isRekFlag()) && (oc.isDriverObject())) {
-				DriverObjectList.addElement(oc);
-			}
-		}
-		RekValidating = false;
-		NeedsRecompute = true;
+	e = c.elements();
+	while (e.hasMoreElements()) {
+	    final ConstructionObject oc = (ConstructionObject) e.nextElement();
+	    if ((oc.isRekFlag()) && (oc.isDriverObject())) {
+		DriverObjectList.addElement(oc);
+	    }
 	}
+	RekValidating = false;
+	NeedsRecompute = true;
+    }
 
 	/**
 	 * Recursive method called by the searchDependencies method
-	 * 
+	 *
 	 * @param o
 	 */
 	public void recursiveSearchDependencies(final ConstructionObject o) {
@@ -337,6 +194,7 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 	/**
 	 * Time consuming method which is called only if it's really necessary :
 	 */
+    @Override
 	public void compute() {
 		// Empty the vector which contains the point set of the plot :
 		V.clear();
@@ -480,9 +338,10 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 	/**
 	 * Check all objects the function depends on. If one of the have changed,
 	 * this function return true.
-	 * 
+	 *
 	 * @return
 	 */
+    @Override
 	public boolean needsToRecompute() {
 		boolean needs = false;
 		final Enumeration pl = DriverObjectList.elements();
@@ -537,10 +396,10 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 	@Override
 	public void updateText() {
 		if (EX != null && EY != null) {
-			setText(text2(Zirkel.name("text.function"), EX.toString(), EY
+			setText(text2(Global.name("text.function"), EX.toString(), EY
 					.toString()));
 		} else {
-			setText(text2(Zirkel.name("text.function"), "", ""));
+			setText(text2(Global.name("text.function"), "", ""));
 		}
 	}
 
@@ -618,95 +477,154 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 	double C1, C2;
 	int C, R, W, H;
 
-	@Override
-	public void paint(final MyGraphics g, final ZirkelCanvas zc) {
-		if (!Valid || mustHide(zc)) {
-			return;
-		}
-		Coordinates C = null;
-		Enumeration e = V.elements();
-		double c, r;
-		g.setColor(this);
-
-		if (Special) {
-			if (Filled) {
-				PF = new FunctionPolygonFiller(g, this, zc.getY(), zc.getY()
-						+ zc.getHeight());
-				while (e.hasMoreElements()) {
-					C = (Coordinates) e.nextElement();
-					PF.add(zc.col(C.X), zc.row(C.Y));
-				}
-				PF.fillPolygon(zc.row(0));
-				e = V.elements();
-				g.setColor(this);
-			}
-
-			while (e.hasMoreElements()) {
-				C = (Coordinates) e.nextElement();
-				PointObject.drawPoint(g, zc, this, C.X, C.Y, Type);
-			}
-		} else if (Tracked) {
-			zc.UniversalTrack.TrackIG.setColor(this);
-			zc.UniversalTrack.setActive(true);
-			final PolygonDrawer pd = new PolygonDrawer(g, this);
-			final PolygonDrawer pdt = new PolygonDrawer(
-					zc.UniversalTrack.TrackIG, this);
-			if (e.hasMoreElements()) {
-				C = (Coordinates) e.nextElement();
-				c0 = zc.col(C.X);
-				r0 = zc.row(C.Y);
-				pd.startPolygon(c0, r0);
-				pdt.startPolygon(c0, r0);
-			}
-			while (e.hasMoreElements()) {
-				C = (Coordinates) e.nextElement();
-				c = zc.col(C.X);
-				r = zc.row(C.Y);
-				if (Math.abs(pd.c() - c) < 1000 && Math.abs(pd.r() - r) < 1000) {
-					pd.drawTo(c, r);
-					pdt.drawTo(c, r);
-				} else {
-					pd.finishPolygon();
-					pdt.finishPolygon();
-					pd.startPolygon(c, r);
-					pdt.startPolygon(c, r);
-				}
-			}
-			pd.finishPolygon();
-			pdt.finishPolygon();
-		} else {
-			if (Filled) {
-				PF = new FunctionPolygonFiller(g, this, zc.getY(), zc.getY()
-						+ zc.getHeight());
-				while (e.hasMoreElements()) {
-					C = (Coordinates) e.nextElement();
-					PF.add(zc.col(C.X), zc.row(C.Y));
-				}
-				PF.fillPolygon(zc.row(0));
-				e = V.elements();
-				g.setColor(this);
-			}
-			final PolygonDrawer pd = new PolygonDrawer(g, this);
-			if (e.hasMoreElements()) {
-				C = (Coordinates) e.nextElement();
-				c0 = zc.col(C.X);
-				r0 = zc.row(C.Y);
-				pd.startPolygon(c0, r0);
-			}
-			while (e.hasMoreElements()) {
-				C = (Coordinates) e.nextElement();
-				c = zc.col(C.X);
-				r = zc.row(C.Y);
-				if (C.join) {
-					pd.drawTo(c, r);
-				} else {
-					pd.finishPolygon();
-					pd.startPolygon(c, r);
-				}
-			}
-			pd.finishPolygon();
-		}
+    @Override
+    public void paint(final MyGraphics g, final ZirkelCanvas zc) {
+	if (!Valid || mustHide(zc)) {
+	    return;
 	}
+	Coordinates C = null;
+	Enumeration e = V.elements();
+	double c, r;
+	g.setColor(this);
+        String s=getDisplayText();
+	if (!s.equals("")) {
+	    g.setLabelColor(this);
+            setFont(g);
+            int n = s.length();
+            if(s.startsWith("$")){//crise de dollarophobie
+		s= s.substring(1, n-1);
+            }
+            if(V.size()>5){
+	    //coordonnées du point d'attache
+            final Coordinates attache=(Coordinates) V.elementAt((int) Math.floor(V.size()/2+3));
+            final Coordinates precedent=(Coordinates) V.elementAt((int) Math.floor(V.size()/2)+2);
+            double Dx=attache.X-precedent.X;
+            double Dy=attache.Y-precedent.Y;
+            double norme=4*Math.sqrt(Dx*Dx+Dy*Dy);
+            drawLabel(g, "$\\mathcal{C}_{"+s+"}$", zc, attache.X, attache.Y,0,0, Dy/norme, -Dx/norme);
+            }
+	}
+
+	if (Special) {
+	    if (Filled) {
+		PF = new FunctionPolygonFiller(g, this, zc.getY(), zc.getY() + zc.getHeight());
+		while (e.hasMoreElements()) {
+		    C = (Coordinates) e.nextElement();
+		    PF.add(zc.col(C.X), zc.row(C.Y));
+		}
+		PF.fillPolygon(zc.row(0));
+		e = V.elements();
+		g.setColor(this);
+	    }
+
+	    while (e.hasMoreElements()) {
+		C = (Coordinates) e.nextElement();
+		PointObject.drawPoint(g, zc, this, C.X, C.Y, Type);
+	    }
+	} else if (Tracked) {
+	    zc.UniversalTrack.TrackIG.setColor(this);
+	    zc.UniversalTrack.setActive(true);
+	    final PolygonDrawer pd = new PolygonDrawer(false,g, this);
+	    final PolygonDrawer pdt = new PolygonDrawer(false,zc.UniversalTrack.TrackIG, this);
+	    if (e.hasMoreElements()) {
+		C = (Coordinates) e.nextElement();
+		c0 = zc.col(C.X);
+		r0 = zc.row(C.Y);
+		pd.startPolygon(c0, r0);
+		pdt.startPolygon(c0, r0);
+	    }
+	    while (e.hasMoreElements()) {
+		C = (Coordinates) e.nextElement();
+		c = zc.col(C.X);
+		r = zc.row(C.Y);
+		if (Math.abs(pd.c() - c) < 1000 && Math.abs(pd.r() - r) < 1000) {
+		    pd.drawTo(c, r);
+		    pdt.drawTo(c, r);
+		} else {
+		    pd.finishPolygon();
+		    pdt.finishPolygon();
+		    pd.startPolygon(c, r);
+		    pdt.startPolygon(c, r);
+		}
+	    }
+	    pd.finishPolygon();
+	    pdt.finishPolygon();
+	} else {
+	    if (Filled) {
+		PF = new FunctionPolygonFiller(g, this, zc.getY(), zc.getY() + zc.getHeight());
+		while (e.hasMoreElements()) {
+		    C = (Coordinates) e.nextElement();
+		    PF.add(zc.col(C.X), zc.row(C.Y));
+		}
+		PF.fillPolygon(zc.row(0));
+		e = V.elements();
+		g.setColor(this);
+	    }
+	    final PolygonDrawer pd = new PolygonDrawer(false,g, this);
+		if (e.hasMoreElements()) {
+		    C = (Coordinates) e.nextElement();
+		    c0 = zc.col(C.X);
+		    r0 = zc.row(C.Y);
+		    pd.startPolygon(c0, r0);
+		}
+		while (e.hasMoreElements()) {
+		    C = (Coordinates) e.nextElement();
+		    c = zc.col(C.X);
+		    r = zc.row(C.Y);
+		    if (C.join) {
+			pd.drawTo(c, r);
+		    } else {
+			pd.finishPolygon();
+			pd.startPolygon(c, r);
+		    }
+		}
+		pd.finishPolygon();
+	}
+
+	/***********************
+	 * Painting the bounds *
+	 ***********************/
+	double w = 2*zc.pointSize()+2*zc.getOne(), x, y;
+
+	if(!VarMin.toString().equals("windowcx-windoww")) {
+	    final Coordinates coord0 = (Coordinates) V.firstElement();
+
+	    if(isMinClosed) {
+		x = zc.col(coord0.X) - zc.pointSize() - zc.getOne();
+		y = zc.row(coord0.Y) - zc.pointSize() - zc.getOne();
+		g.fillOval(x, y, w, w, this.getColor());
+	    } else if(isMinOpen) {
+		//final Coordinates coord1 = (Coordinates) V.elementAt(Math.min(0, V.size()));
+                final Coordinates coord1 = (Coordinates) V.elementAt(V.size()==1?0:1);
+		double dx = zc.col(coord0.X) - zc.col(coord1.X);
+		double dy = zc.row(coord0.Y) - zc.row(coord1.Y);
+		x = w/2*dx/(Math.sqrt(dx*dx+dy*dy)) + zc.col(coord0.X) - zc.pointSize() - zc.getOne();
+		y = w/2*dy/(Math.sqrt(dx*dx+dy*dy)) + zc.row(coord0.Y) - zc.pointSize() - zc.getOne();
+
+		double alpha = Math.atan2(coord0.Y-coord1.Y, coord0.X-coord1.X)*180/Math.PI;
+		g.drawArc(x, y, w, w, alpha+90, 180);
+	    }
+	}
+	if(!VarMax.toString().equals("windowcx+windoww")) {
+	    final Coordinates coord0=(Coordinates) V.lastElement();
+
+	    if(isMaxClosed) {
+		w = 2*zc.pointSize()+2*zc.getOne();
+		x = zc.col(coord0.X)-zc.pointSize()-zc.getOne();
+		y = zc.row(coord0.Y)-zc.pointSize()-zc.getOne();
+		g.fillOval(x, y, w, w, this.getColor());
+	    } else if(isMaxOpen) {
+		final Coordinates coord1 = (Coordinates) V.elementAt(Math.max(V.size()-2,0));
+                double dx = zc.col(coord0.X) - zc.col(coord1.X);
+		double dy = zc.row(coord0.Y) - zc.row(coord1.Y);
+		x = w/2*dx/(Math.sqrt(dx*dx+dy*dy)) + zc.col(coord0.X) - zc.pointSize() - zc.getOne();
+		y = w/2*dy/(Math.sqrt(dx*dx+dy*dy)) + zc.row(coord0.Y) - zc.pointSize() - zc.getOne();
+
+		double alpha = Math.atan2(coord0.Y-coord1.Y, coord0.X-coord1.X)*180/Math.PI;
+		g.drawArc(x, y, w, w, alpha+90, 180);
+	    }
+	}
+    }
 
 	@Override
 	public double getValue() throws ConstructionException {
@@ -793,65 +711,34 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 
 	public boolean EditAborted;
 
-	@Override
-	public void edit(final ZirkelCanvas zc) {
-		ObjectEditDialog d;
-		if (!rene.zirkel.Zirkel.IsApplet) {
-			eric.JGlobals.EditObject(this);
-			return;
-		}
-		while (true) {
-			d = new CurveEditDialog(zc, this);
-			d.setVisible(true);
-			EditAborted = false;
-			if (d.isAborted()) {
-				EditAborted = true;
-				break;
-			} else if (!EX.isValid()) {
-				final Frame F = zc.getFrame();
-				final Warning w = new Warning(F, EX.getErrorText(), Zirkel
-						.name("warning"), true);
-				w.center(F);
-				w.setVisible(true);
-			} else if (!EY.isValid()) {
-				final Frame F = zc.getFrame();
-				final Warning w = new Warning(F, EY.getErrorText(), Zirkel
-						.name("warning"), true);
-				w.center(F);
-				w.setVisible(true);
-			} else {
-				break;
-			}
-		}
-		validate();
-		updateText();
-		zc.getConstruction().updateCircleDep();
-		zc.repaint();
-		if (d.wantsMore()) {
-			new EditConditionals(zc.getFrame(), this);
-			validate();
-		}
-	}
 
-	@Override
-	public void printArgs(final XmlWriter xml) {
-		xml.printArg("x", EX.toString());
-		xml.printArg("y", EY.toString());
-		xml.printArg("var", getVar());
-		xml.printArg("min", "" + VarMin);
-		xml.printArg("max", "" + VarMax);
-		xml.printArg("d", "" + DVar);
-		if (Special) {
-			xml.printArg("special", "true");
-		}
-		printType(xml);
-		if (Filled) {
-			xml.printArg("filled", "true");
-		}
-		if (getCenter() != null) {
-			xml.printArg("center", getCenter().getName());
-		}
+
+    @Override
+    public void printArgs(final XmlWriter xml) {
+	xml.printArg("x", EX.toString());
+	xml.printArg("y", EY.toString());
+	xml.printArg("var", getVar());
+	xml.printArg("min", "" + VarMin);
+	xml.printArg("max", "" + VarMax);
+	xml.printArg("d", "" + DVar);
+	if (Special) {
+	    xml.printArg("special", "true");
 	}
+	printType(xml);
+	if (Filled) {
+	    xml.printArg("filled", "true");
+	}
+	if (getCenter() != null) {
+	    xml.printArg("center", getCenter().getName());
+	}
+        xml.printArg("color", ""+getColorIndex());
+	if(isMinOpen || isMinClosed) {
+	    xml.printArg("minbound", isMinOpen?"0":"1"); //0 = open ; 1 = closed
+	}
+	if(isMaxOpen || isMaxClosed) {
+	    xml.printArg("maxbound", isMaxOpen?"0":"1");
+	}
+    }
 
 	@Override
 	public void setType(final int type) {
@@ -891,6 +778,7 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 
 		final FunctionObject fo = new FunctionObject(getConstruction());
 		fo.copyProperties(this);
+		fo.setFilled(this.isFilled()); //bug fix concerning filled curves in macro constructions
 
 		fo.EX = new Expression(EX.toString(), getConstruction(), fo, Var);
 		fo.EY = new Expression(EY.toString(), getConstruction(), fo, Var);
@@ -968,6 +856,7 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 		}
 	}
 
+    @Override
 	public double evaluateF(final double x) throws ConstructionException {
 		X[0] = x;
 		for (int i = 1; i < X.length; i++) {
@@ -1005,7 +894,7 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 
 		} catch (final Exception e) {
 			Valid = false;
-			return 1000;
+			return Integer.MAX_VALUE;
 		}
 
 		try {
@@ -1068,7 +957,7 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 
 		} catch (final Exception e) {
 			Valid = false;
-			return 1000;
+			return Integer.MAX_VALUE;
 		}
 
 		// Otherwise, at Least get the approx coordinates on the polygon :
@@ -1126,9 +1015,10 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 		} else {
 			P.Valid = false;
 		}
-		return 1000;
+		return Integer.MAX_VALUE;
 	}
 
+    @Override
 	public void project(final PointObject P) {
 		double varmin, varmax, dvar;
 		try {
@@ -1404,70 +1294,108 @@ PointonObject, HeavyObject, DriverObject, Evaluator {
 		Special = f;
 	}
 
-	public void project(final PointObject P, final double alpha) {
-		project(P);
-	}
+    @Override
+    public void project(final PointObject P, final double alpha) {
+	project(P);
+    }
 
-	@Override
-	public boolean maybeTransparent() {
-		return true;
-	}
+    @Override
+    public boolean maybeTransparent() {
+	return true;
+    }
 
-	@Override
-	public boolean canDisplayName() {
-		return false;
-	}
+    @Override
+    public boolean canDisplayName() {
+	return true;
+    }
 
-	public void setCenter(final String s) {
-		if (Cn == null) {
-			return;
-		}
-		Center = new Expression("@\"" + s + "\"", Cn, this);
-	}
+    @Override
+    public boolean showValue(){
+	return false;
+    }
 
-	@Override
-	public boolean isFilledForSelect() {
-		return false;
+    public void setCenter(final String s) {
+    	if (Cn == null) {
+	    return;
 	}
+	Center = new Expression("@\"" + s + "\"", Cn, this);
+    }
 
-	public PointObject getCenter() {
-		try {
-			return (PointObject) Center.getObject();
-		} catch (final Exception e) {
-			return null;
-		}
+    @Override
+    public boolean isFilledForSelect() {
+	return false;
+    }
+
+    public PointObject getCenter() {
+	try {
+	    return (PointObject) Center.getObject();
+	} catch (final Exception e) {
+	    return null;
 	}
+    }
 
-	public String getVar() {
-		String vars = Var[0];
-		for (int i = 1; i < Var.length; i++) {
-			vars = vars + " " + Var[i];
-		}
-		return vars;
+    public String getVar() {
+	String vars = Var[0];
+	for (int i = 1; i < Var.length; i++) {
+	    vars = vars + " " + Var[i];
 	}
+	return vars;
+    }
 
-	public boolean canInteresectWith(final ConstructionObject o) {
-		return true;
-	}
+    @Override
+    public boolean canInteresectWith(final ConstructionObject o) {
+	return true;
+    }
 
-	@Override
-	public boolean isDriverObject() {
-		return true;
-	}
+    @Override
+    public boolean isDriverObject() {
+	return true;
+    }
 
-	public boolean somethingChanged() {
-		boolean b = !EX.toString().equals(LASTEX);
-		b = b || !EY.toString().equals(LASTEY);
+    @Override
+    public boolean somethingChanged() {
+	boolean b = !EX.toString().equals(LASTEX);
+	b = b || !EY.toString().equals(LASTEY);
+	return b;
+    }
 
-		return b;
-	}
+    @Override
+    public void clearChanges() {
+	LASTEX = EX.toString();
+	LASTEY = EY.toString();
+    }
 
-	public void clearChanges() {
-		LASTEX = EX.toString();
-		LASTEY = EY.toString();
-	}
+    @Override
+    public void repulse(final PointObject P) {
+	project(P);
+    }
 
-	public void repulse(final PointObject P) {
-		project(P);
-	}
+    /******************************
+     * Closed or Open Intervals ***
+    *******************************/
+    public void setMinClosed(boolean b) {
+	isMinClosed = b;
+    }
+    public void setMinOpen(boolean b) {
+	isMinOpen = b;
+    }
+    public boolean getMinClosed() {
+	return isMinClosed;
+    }
+    public boolean getMinOpen() {
+	return isMinOpen;
+    }
+    
+    public void setMaxClosed(boolean b) {
+	isMaxClosed = b;
+    }
+    public void setMaxOpen(boolean b) {
+	isMaxOpen = b;
+    }
+    public boolean getMaxClosed() {
+	return isMaxClosed;
+    }
+    public boolean getMaxOpen() {
+	return isMaxOpen;
+    }
 }
