@@ -1,5 +1,5 @@
-/* 
- 
+/*
+
 Copyright 2006 Rene Grothmann, modified by Eric Hakenholz
 
 This file is part of C.a.R. software.
@@ -15,30 +15,27 @@ This file is part of C.a.R. software.
 
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
- 
+
  */
- 
- 
+
+
  package rene.zirkel.objects;
 
 // file: SegmentObject.java
-import java.awt.Color;
-import java.awt.Frame;
+import java.awt.Rectangle;
 import java.util.Enumeration;
-
-import rene.dialogs.Warning;
 import rene.gui.Global;
 import rene.util.xml.XmlWriter;
-import rene.zirkel.Zirkel;
 import rene.zirkel.ZirkelCanvas;
 import rene.zirkel.construction.Construction;
 import rene.zirkel.construction.ConstructionException;
 import rene.zirkel.construction.Count;
 import rene.zirkel.expression.Expression;
+import rene.zirkel.expression.ExpressionColor;
 import rene.zirkel.expression.InvalidException;
+import rene.zirkel.graphics.MainGraphics;
 import rene.zirkel.graphics.MyGraphics;
-import rene.zirkel.graphics.MyGraphics13;
-import eric.JGlobals;
+
 
 /**
  * @author Rene Class for segments, derived from LineObject, TwoPointLineObject.
@@ -48,20 +45,31 @@ import eric.JGlobals;
 public class SegmentObject extends TwoPointLineObject {
 
 	static Count N = new Count();
+	protected boolean Is3D; //Dibs : 3D ?
+	protected double X3D1, Y3D1, Z3D1, X3D2, Y3D2, Z3D2, DX3D, DY3D, DZ3D; //Dibs
 	protected boolean Fixed = false; // fixed length?
+	protected boolean Fixed3D = false; // fixed length?
 	Expression E; // expression to fix the length.
+	Expression E3D;
 	boolean ExpressionFailed; // invalid expression?
-	boolean Arrow = false; // draw as arrow.
+	public boolean Arrow; // draw as arrow.
 	int code_symbol = 0;
 
 	public SegmentObject(final Construction c, final PointObject p1,
 			final PointObject p2) {
 		super(c, p1, p2);
+		if (p1.is3D()&&p2.is3D()) Is3D=true;
+		Arrow = false;
 		validate();
 		updateText();
 		Unit = Global.getParameter("unit.length", "");
 	}
 
+	@Override
+        public String getCDPDisplayValue(){
+	    	return Global.getLocaleNumber(R, "lengths");
+        }
+
 	@Override
 	public String getTag() {
 		return "Segment";
@@ -78,11 +86,11 @@ public class SegmentObject extends TwoPointLineObject {
 	// }
 	@Override
 	public void setDefaults() {
-		Arrow = Cn.Vectors;
+		//Arrow = Cn.Vectors; //plus nécessaire
 		setShowName(Global.getParameter("options.segment.shownames", false));
 		setShowValue(Global.getParameter("options.segment.showvalues", false));
 		setColor(Global.getParameter("options.segment.color", 0), Global
-				.getParameter("options.segment.pcolor", (Color) null));
+				.getParameter("options.segment.pcolor", (ExpressionColor) null, this));
 		setColorType(Global.getParameter("options.segment.colortype", 0));
 		setHidden(Cn.Hidden);
 		setObtuse(Cn.Obtuse);
@@ -93,11 +101,10 @@ public class SegmentObject extends TwoPointLineObject {
 
 	@Override
 	public void setTargetDefaults() {
-
 		setShowName(Global.getParameter("options.segment.shownames", false));
 		setShowValue(Global.getParameter("options.segment.showvalues", false));
 		setColor(Global.getParameter("options.segment.color", 0), Global
-				.getParameter("options.segment.pcolor", (Color) null));
+				.getParameter("options.segment.pcolor", (ExpressionColor) null, this));
 		setColorType(Global.getParameter("options.segment.colortype", 0));
 		setLarge(Global.getParameter("options.segment.large", false));
 		setBold(Global.getParameter("options.segment.bold", false));
@@ -106,14 +113,14 @@ public class SegmentObject extends TwoPointLineObject {
 	@Override
 	public void updateText() {
 		if (!Fixed) {
-			setText(text2(Zirkel.name("text.segment"), P1.getName(), P2
+			setText(text2(Global.name("text.segment"), P1.getName(), P2
 					.getName()));
 		} else {
 			if (E == null) {
-				setText(text3(Zirkel.name("text.segment.fixed"), P1.getName(),
+				setText(text3(Global.name("text.segment.fixed"), P1.getName(),
 						P2.getName(), "" + round(R)));
 			} else {
-				setText(text3(Zirkel.name("text.segment.fixed"), P1.getName(),
+				setText(text3(Global.name("text.segment.fixed"), P1.getName(),
 						P2.getName(), "\"" + E.toString() + "\""));
 			}
 		}
@@ -131,15 +138,27 @@ public class SegmentObject extends TwoPointLineObject {
 			Y1 = P1.getY();
 			X2 = P2.getX();
 			Y2 = P2.getY();
-
 			// compute normalized vector in the direction of the line:
 			DX = X2 - X1;
 			DY = Y2 - Y1;
 			R = Math.sqrt(DX * DX + DY * DY);
 			// System.out.println("X1="+X1+" Y1="+Y1+" | X2="+X2+" Y2="+Y2+" R="+R);
+			if (P1.is3D()&&P2.is3D()) Is3D=true; // Dibs last updated
+			if (Is3D) {					//Dibs
+				X3D1 = P1.getX3D();
+				Y3D1 = P1.getY3D();
+				Z3D1 = P1.getZ3D();
+				X3D2 = P2.getX3D();
+				Y3D2 = P2.getY3D();
+				Z3D2 = P2.getZ3D();
+				DX3D = X3D2-X3D1;
+				DY3D = Y3D2-Y3D1;
+				DZ3D = Z3D2-Z3D1;
+				R3D = Math.sqrt(DX3D * DX3D + DY3D * DY3D + DZ3D * DZ3D);
+			}
 
 			// if fixed, move the moveable endpoint.
-			if (Fixed && E != null) {
+			if (Fixed && E != null&&!is3D()) {
 				try {
 					final double FixedR = E.getValue();
 					// System.out.println(R+" "+FixedR);
@@ -201,6 +220,75 @@ public class SegmentObject extends TwoPointLineObject {
 					ExpressionFailed = true;
 					Valid = false;
 					R = 0;
+					R3D=0;
+					return;
+				}
+			}
+			else if (Fixed3D && E3D != null) { // pour plus tard...
+				try {
+					final double FixedR3D = E3D.getValue();
+					if (FixedR3D < 1e-8) {
+						R3D = 0;
+						ExpressionFailed = true;
+						Valid = false;
+						return;
+					}
+					boolean movefirst = P1.moveableBy(this), movesecond = P2
+					.moveableBy(this);
+					if (P2.getBound() != null) {
+						final ConstructionObject bound = P2.getBound();
+						if (bound instanceof RayObject) {
+							if (((RayObject) bound).getP1() == P1) {
+								movesecond = true;
+							}
+						}
+					} else if (P1.getBound() != null) {
+						final ConstructionObject bound = P1.getBound();
+						if (bound instanceof RayObject) {
+							if (((RayObject) bound).getP1() == P2) {
+								movefirst = true;
+								movesecond = false;
+							}
+						}
+					}
+					if (movesecond) {
+						if (R3D < 1e-10) {
+							P2.move3D(X3D1 + FixedR3D, Y3D1, Z3D1);
+						} else {
+							P2.move3D(X3D1 + FixedR3D * DX3D / R3D, Y3D1 + FixedR3D * DY3D / R3D, Z3D1 + FixedR3D * DZ3D / R3D);
+						}
+						P1.setUseAlpha(false);
+						// System.out.println("Move "+P2.getName());
+					} else if (movefirst) {
+						if (R < 1e-10) {
+							P1.move3D(X3D2 - FixedR3D, Y3D2, Z3D2);
+						} else {
+							P1.move3D(X3D2 - FixedR3D * DX3D / R3D, Y3D2 - FixedR3D * DY3D / R3D, Z3D2 - FixedR3D * DZ3D / R3D);
+						}
+						P2.setUseAlpha(false);
+						// System.out.println("Move "+P1.getName());
+					} else {
+						Fixed3D = false; // no moveable endpoint!
+					}
+					if (Fixed3D) {
+						X3D1 = P1.getX3D();
+						Y3D1 = P1.getY3D();
+						Z3D1 = P1.getZ3D();
+						X3D2 = P2.getX3D();
+						Y3D2 = P2.getY3D();
+						Z3D2 = P2.getZ3D();
+						DX3D = X3D2-X3D1;
+						DY3D = Y3D2-Y3D1;
+						DZ3D = Z3D2-Z3D1;
+						R3D = Math.sqrt(DX3D * DX3D + DY3D * DY3D + DZ3D * DZ3D);
+						P2.movedBy(this);
+						P1.movedBy(this);
+					}
+				} catch (final Exception e) {
+					ExpressionFailed = true;
+					Valid = false;
+					R = 0;
+					R3D=0;
 					return;
 				}
 			}
@@ -213,6 +301,15 @@ public class SegmentObject extends TwoPointLineObject {
 				DX /= R;
 				DY /= R;
 			}
+			if (R3D < 1e-10) {
+				R3D = 0;
+				DX3D = 1;
+				DY3D = 0;
+				DZ3D=0;
+			} else {
+				DX3D /= R3D;
+				DY3D /= R3D;
+			}
 		}
 	}
 
@@ -224,8 +321,8 @@ public class SegmentObject extends TwoPointLineObject {
 		final double c1 = zc.col(X1), r1 = zc.row(Y1), c2 = zc.col(X2), r2 = zc
 		.row(Y2);
 		if (visible(zc)) {
-			if (isStrongSelected() && g instanceof MyGraphics13) {
-				((MyGraphics13) g).drawMarkerLine(c1, r1, c2, r2);
+			if (isStrongSelected() && g instanceof MainGraphics) {
+				((MainGraphics) g).drawMarkerLine(c1, r1, c2, r2);
 			}
 			g.setColor(this);
 			if (tracked()) {
@@ -235,11 +332,11 @@ public class SegmentObject extends TwoPointLineObject {
 
 			if (code_symbol > 0) {
 				// length of the tick mark :
-				final double rr = 7;
+				final double rr = 7*Cn.getOne();
 				// distance between two marks :
-				final double dd = 3;
+				final double dd = 3*Cn.getOne();
 				// oblique de la marque :
-				final double ob = 2;
+				final double ob = 2*Cn.getOne();
 
 				final double cM = (c1 + c2) / 2, rM = (r1 + r2) / 2;
 				final double A = c2 - cM, B = r2 - rM;
@@ -287,8 +384,8 @@ public class SegmentObject extends TwoPointLineObject {
 			if (Arrow) // draw as arrow!
 			{
 				final double a = Math.PI * 0.9;
-				final double r = zc.dx(zc.scale(Global.getParameter(
-						"arrowsize", 15))); // 10 pixel on the screen
+				final double r = zc.dx(Cn.getOne()*Global.getParameter(
+						"arrowsize", 15)); // 10 pixel on the screen
 				final double[] cols = new double[3];
 				cols[0] = c2;
 				cols[1] = zc
@@ -337,12 +434,20 @@ public class SegmentObject extends TwoPointLineObject {
 	// { return
 	// eric.JGlobals.fixDecimal(""+round(R,ZirkelCanvas.LengthsFactor));
 	// }
+	
 	@Override
 	public String getDisplayValue() {
 		// return ""+round(R,ZirkelCanvas.LengthsFactor);
-		return JGlobals.getLocaleNumber(R, "lengths");
+		if (!Is3D) return Global.getLocaleNumber(R, "lengths");
+	    else return Global.getLocaleNumber(R3D, "lengths");
 	}
 
+        @Override
+    public boolean isInRect(Rectangle r, ZirkelCanvas zc){
+        return ((r.contains(zc.col(P1.getX()),zc.row(P1.getY())))&&
+                (r.contains(zc.col(P2.getX()),zc.row(P2.getY()))));
+    }
+
 	/**
 	 * see, if a point is on the segment or near to it.
 	 */
@@ -387,19 +492,22 @@ public class SegmentObject extends TwoPointLineObject {
 	 */
 	@Override
 	public boolean onlynearto(final int c, final int r, final ZirkelCanvas zc) {
-		return R < zc.dx(3 * (int) zc.pointSize());
+		return R < zc.dx(3 *zc.pointSize());
 	}
 
 	@Override
 	public void printArgs(final XmlWriter xml) {
 		xml.printArg("from", P1.getName());
 		xml.printArg("to", P2.getName());
+		if (Is3D) {
+			xml.printArg("is3D", "true");
+		}
 		if (Fixed && E != null) {
 			xml.printArg("fixed", E.toString());
 		}
-		if (Arrow) {
-			xml.printArg("arrow", "true");
-		}
+//		if (Arrow) {
+//			xml.printArg("arrow", "true");
+//		} //plus nécessaire
 		if (code_symbol > 0) {
 			xml.printArg("code_symbol", "" + code_symbol);
 		}
@@ -410,11 +518,26 @@ public class SegmentObject extends TwoPointLineObject {
 	public double getLength() {
 		return R;
 	}
+	
+	@Override
+	public double getLength3D() {
+		return R3D;
+	}
+	
+	public boolean is3D() {
+    	return Is3D;
+    }
+
 
 	@Override
 	public boolean fixed() {
 		return Fixed;
 	}
+	
+	@Override
+	public boolean fixed3D() {
+		return Fixed3D;
+	}
 
 	@Override
 	public void setFixed(final boolean flag, final String s)
@@ -431,6 +554,23 @@ public class SegmentObject extends TwoPointLineObject {
 		}
 		updateText();
 	}
+	
+	@Override
+	public void setFixed3D(final boolean flag, final String s)
+	throws ConstructionException {
+		if (!flag || s.equals("")) {
+			Fixed3D = false;
+			E3D = null;
+		} else {
+			E3D = new Expression(s, getConstruction(), this);
+			if (!E3D.isValid()) {
+				throw new ConstructionException(E.getErrorText());
+			}
+			Fixed3D = true;
+		}
+		updateText();
+	}
+	
 
 	@Override
 	public void round() {
@@ -485,21 +625,7 @@ public class SegmentObject extends TwoPointLineObject {
 						Y2, l.Y1));
 	}
 
-	@Override
-	public void edit(final ZirkelCanvas zc) {
-		if (!rene.zirkel.Zirkel.IsApplet) {
-			eric.JGlobals.EditObject(this);
-			return;
-		}
-		super.edit(zc);
-		if (E != null && !E.isValid()) {
-			final Frame F = zc.getFrame();
-			final Warning w = new Warning(F, E.getErrorText(), Zirkel
-					.name("warning"), true);
-			w.center(F);
-			w.setVisible(true);
-		}
-	}
+
 
 	public boolean isValidFix() {
 		return E != null && E.isValid();
@@ -513,6 +639,14 @@ public class SegmentObject extends TwoPointLineObject {
 			return "" + round(R);
 		}
 	}
+	
+	public String getStringLength3D() {
+		if (E3D != null) {
+			return E3D.toString();
+		} else {
+			return "" + round(R3D);
+		}
+	}
 
 	public int getSegmentCode() {
 		return code_symbol;
@@ -527,7 +661,16 @@ public class SegmentObject extends TwoPointLineObject {
 		if (!Valid) {
 			throw new InvalidException("exception.invalid");
 		} else {
-			return R;
+			if (!P1.is3D()||!P2.is3D()) return R;
+			else return R3D;
+		}
+	}
+	
+	public double getValue3D() throws ConstructionException {
+		if (!Valid) {
+			throw new InvalidException("exception.invalid");
+		} else {
+			return R3D;
 		}
 	}
 
@@ -544,18 +687,27 @@ public class SegmentObject extends TwoPointLineObject {
 
 	@Override
 	public Enumeration depending() {
-		if (!Fixed || E == null) {
+		if (!Fixed &&!Fixed3D) {
 			return super.depending();
 		} else {
+			if (E!= null)  {
 			super.depending();
 			final Enumeration e = E.getDepList().elements();
 			while (e.hasMoreElements()) {
 				DL.add((ConstructionObject) e.nextElement());
+				}
 			}
+			if (E3D!=null) {
+					final Enumeration f = E3D.getDepList().elements();
+					while (f.hasMoreElements()) {
+						DL.add((ConstructionObject) f.nextElement());
+					}
+				}
 			return DL.elements();
 		}
 	}
 
+
 	public void setArrow(final boolean arrow) {
 		Arrow = arrow;
 	}
@@ -584,4 +736,12 @@ public class SegmentObject extends TwoPointLineObject {
 		}
 		return false;
 	}
+        
+        @Override
+        public void setFixed(final boolean bool) {
+            if (bool) {
+                E = new Expression(this.getStringLength(), getConstruction(), this);
+            }
+            Fixed=bool;
+        }
 }
