@@ -1,5 +1,5 @@
-/* 
- 
+/*
+
 Copyright 2006 Rene Grothmann, modified by Eric Hakenholz
 
 This file is part of C.a.R. software.
@@ -15,115 +15,29 @@ This file is part of C.a.R. software.
 
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
- 
+
  */
- 
- 
+
+
  package rene.zirkel.objects;
 
 // file: TrackObject.java
-import java.awt.Checkbox;
-import java.awt.Color;
 import java.util.Enumeration;
 import java.util.Vector;
-
-import javax.swing.JPanel;
-
 import rene.gui.Global;
-import rene.gui.IconBar;
-import rene.gui.MyLabel;
-import rene.gui.MyTextField;
 import rene.util.xml.XmlWriter;
-import rene.zirkel.Zirkel;
 import rene.zirkel.ZirkelCanvas;
 import rene.zirkel.construction.Construction;
 import rene.zirkel.construction.ConstructionException;
 import rene.zirkel.construction.Count;
-import rene.zirkel.dialogs.EditConditionals;
-import rene.zirkel.dialogs.ObjectEditDialog;
+import rene.zirkel.expression.ExpressionColor;
+import rene.zirkel.graphics.MainGraphics;
 import rene.zirkel.graphics.MyGraphics;
-import rene.zirkel.graphics.MyGraphics13;
 import rene.zirkel.graphics.PolygonDrawer;
 import rene.zirkel.graphics.PolygonFiller;
 import rene.zirkel.structures.Coordinates;
 
-class TrackEditDialog extends ObjectEditDialog {
 
-	/**
-	 * 
-	 */
-	private static final long serialVersionUID = 1L;
-	IconBar IC, TypeIB;
-	Checkbox Fixed, Discrete;
-	MyTextField DMin;
-
-	public TrackEditDialog(final ZirkelCanvas zc, final TrackObject o) {
-		super(zc.getFrame(), Zirkel.name("edit.function.title"), o, "function");
-	}
-
-	@Override
-	public void addFirst(final JPanel P) {
-		Fixed = new Checkbox("");
-		Fixed.setState(O.isFixed());
-		P.add(new MyLabel(Zirkel.name("edit.fixed")));
-		P.add(Fixed);
-		DMin = new MyTextField("" + ((TrackObject) O).getDMin());
-		P.add(new MyLabel(Zirkel.name("edit.track.dmin")));
-		P.add(DMin);
-	}
-
-	@Override
-	public void addSecond(final JPanel P) {
-		final TrackObject T = (TrackObject) O;
-
-		IC = new IconBar(F);
-		IC.setIconBarListener(this);
-		IC.addOnOffLeft("filled");
-		IC.setState("filled", T.isFilled());
-		IC.setIconBarListener(this);
-		P.add(new MyLabel(""));
-		P.add(IC);
-
-		TypeIB = new IconBar(F);
-		TypeIB.addToggleGroupLeft("type", 6);
-		TypeIB.toggle("type", T.getType());
-		P.add(new MyLabel(""));
-		P.add(TypeIB);
-
-		P.add(new MyLabel(Zirkel.name("edit.discrete")));
-		P.add(Discrete = new Checkbox());
-		Discrete.setState(T.isDiscrete());
-
-	}
-
-	@Override
-	public void iconPressed(final String o) {
-		if (o.equals("filled")) {
-			if (IC.getState("filled")) {
-				IB.setState("isback", true);
-				ThicknessIB.setEnabled("solid", true);
-			} else {
-				IB.setState("isback", false);
-				ThicknessIB.setState("solid", false);
-				ThicknessIB.setEnabled("solid", false);
-			}
-		}
-		super.iconPressed(o);
-	}
-
-	@Override
-	public void setAction() {
-		final TrackObject f = (TrackObject) O;
-		f.setFixed(Fixed.getState());
-		f.setFilled(IC.getState("filled"));
-		try {
-			f.setDMin(new Double(DMin.getText()).doubleValue());
-		} catch (final Exception e) {
-		}
-		f.setType(TypeIB.getToggleState("type"));
-		f.setDiscrete(Discrete.getState());
-	}
-}
 
 /**
  * This object contains an automatic track. It is saved in the construction like
@@ -175,7 +89,7 @@ public class TrackObject extends ConstructionObject implements PointonObject {
 		setShowName(Global.getParameter("options.locus.shownames", false));
 		setShowValue(Global.getParameter("options.locus.showvalues", false));
 		setColor(Global.getParameter("options.locus.color", 0), Global
-				.getParameter("options.locus.pcolor", (Color) null));
+				.getParameter("options.locus.pcolor", (ExpressionColor) null, this));
 		setColorType(Global.getParameter("options.locus.colortype", 0));
 		setFilled(Global.getParameter("options.locus.filled", false));
 		setHidden(Cn.Hidden);
@@ -190,7 +104,7 @@ public class TrackObject extends ConstructionObject implements PointonObject {
 		setShowName(Global.getParameter("options.locus.shownames", false));
 		setShowValue(Global.getParameter("options.locus.showvalues", false));
 		setColor(Global.getParameter("options.locus.color", 0), Global
-				.getParameter("options.locus.pcolor", (Color) null));
+				.getParameter("options.locus.pcolor", (ExpressionColor) null, this));
 		setColorType(Global.getParameter("options.locus.colortype", 0));
 		setFilled(Global.getParameter("options.locus.filled", false));
 	}
@@ -208,10 +122,10 @@ public class TrackObject extends ConstructionObject implements PointonObject {
 	@Override
 	public void updateText() {
 		if (PM != null) {
-			setText(text3(Zirkel.name("text.track"), P.getName(), PM.getName(),
+			setText(text3(Global.name("text.track"), P.getName(), PM.getName(),
 					O.getName()));
 		} else {
-			setText(text2(Zirkel.name("text.trackof"), P.getName(), O.getName()));
+			setText(text2(Global.name("text.trackof"), P.getName(), O.getName()));
 		}
 	}
 
@@ -232,8 +146,8 @@ public class TrackObject extends ConstructionObject implements PointonObject {
 		Coordinates C;
 		Enumeration e = V.elements();
 		double c0, r0, c, r;
-		if (!Discrete && isStrongSelected() && g instanceof MyGraphics13) {
-			final PolygonDrawer pm = new PolygonDrawer(g, this);
+		if (!Discrete && isStrongSelected() && g instanceof MainGraphics) {
+			final PolygonDrawer pm = new PolygonDrawer(false,g, this);
 
 			pm.useAsMarker();
 			if (e.hasMoreElements()) {
@@ -326,7 +240,7 @@ public class TrackObject extends ConstructionObject implements PointonObject {
 			}
 		} else {
 
-			PolygonDrawer pd = new PolygonDrawer(g, this);
+			PolygonDrawer pd = new PolygonDrawer(false,g, this);
 			if (isFilled()) {
 				if (PF == null) {
 					PF = new PolygonFiller(g, this);
@@ -371,7 +285,7 @@ public class TrackObject extends ConstructionObject implements PointonObject {
 			for (int i = 0; i < PN; i++) {
 				e = VO[i].elements();
 				g.setColor(PO[i]);
-				pd = new PolygonDrawer(g, PO[i]);
+				pd = new PolygonDrawer(false,g, PO[i]);
 
 				if (e.hasMoreElements()) {
 					C = (Coordinates) e.nextElement();
@@ -591,12 +505,12 @@ public class TrackObject extends ConstructionObject implements PointonObject {
 	 * moving point moves on some object, the coordinates of the tracked points
 	 * or the intersections of the tracked lines are stored, as well as the
 	 * positions of the moved point.
-	 * 
+	 *
 	 * But if the tracked point gets invalid, the movement reverses and the
 	 * interesections change.
-	 * 
+	 *
 	 * Moreover, there is a list of secondary tracked objects.
-	 * 
+	 *
 	 * @param zc
 	 */
 	public synchronized void docompute(final ZirkelCanvas zc) {
@@ -1234,6 +1148,60 @@ public class TrackObject extends ConstructionObject implements PointonObject {
 		}
 	}
 
+    public synchronized int getDistance(final PointObject P) {
+		final Enumeration e = V.elements();
+		double x = 0, y = 0, x0 = 0, y0 = 0, dmin = 0;
+		boolean started = false;
+		while (e.hasMoreElements()) {
+			final Coordinates c = (Coordinates) e.nextElement();
+			final double x1 = c.X;
+			final double y1 = c.Y;
+			if (!started) {
+				dmin = Math.sqrt((P.getX() - x1) * (P.getX() - x1)
+						+ (P.getY() - y1) * (P.getY() - y1));
+				x0 = x = x1;
+				y0 = y = y1;
+				started = true;
+			} else {
+				if (c.flag) {
+					double h = (x1 - x0) * (x1 - x0) + (y1 - y0) * (y1 - y0);
+					if (h < 1e-10) {
+						h = 1e-10;
+					}
+					double g = (P.getX() - x0) * (x1 - x0) + (P.getY() - y0)
+					* (y1 - y0);
+					if (g < 0) {
+						g = 0;
+					}
+					if (g > h) {
+						g = h;
+					}
+					final double x2 = x0 + g / h * (x1 - x0), y2 = y0 + g / h
+					* (y1 - y0);
+					final double d = Math.sqrt((P.getX() - x2)
+							* (P.getX() - x2) + (P.getY() - y2)
+							* (P.getY() - y2));
+					if (d < dmin) {
+						dmin = d;
+						x = x2;
+						y = y2;
+					}
+				}
+				x0 = x1;
+				y0 = y1;
+			}
+		}
+		if (started) {
+			P.Valid = true;
+            final double dd = Math.sqrt((P.getX() - x) * (P.getX() - x)
+					+ (P.getY() - y) * (P.getY() - y));
+			return (int) Math.round(dd * Cn.getPixel());
+		} else {
+			P.Valid = false;
+		}
+        return Integer.MAX_VALUE;
+	}
+
 	@Override
 	public String getDisplayValue() {
 		try {
@@ -1247,22 +1215,7 @@ public class TrackObject extends ConstructionObject implements PointonObject {
 		project(P);
 	}
 
-	@Override
-	public void edit(final ZirkelCanvas zc) {
-		if (!rene.zirkel.Zirkel.IsApplet) {
-			eric.JGlobals.EditObject(this);
-			return;
-		}
 
-		final ObjectEditDialog d = new TrackEditDialog(zc, this);
-		d.setVisible(true);
-		zc.repaint();
-		validate();
-		if (d.wantsMore()) {
-			new EditConditionals(zc.getFrame(), this);
-			validate();
-		}
-	}
 
 	@Override
 	public boolean canDisplayName() {
