@@ -23,11 +23,22 @@ This file is part of C.a.R. software.
 
 // file: CoordinatesXY.java
 
-public class CoordinatesXY {
-	public double X, Y;
+public class CoordinatesXY implements Comparable<CoordinatesXY>{
+	public double X=Double.NaN, Y=Double.NaN;
 
 	public CoordinatesXY(final double x, final double y) {
 		X = x;
 		Y = y;
 	}
+        public CoordinatesXY(){
+            
+        }
+
+    public int compareTo(CoordinatesXY o) {
+        if (Double.isNaN(X)) return -1;
+        if (Double.isNaN(o.X)) return 1;
+        if (o.X==X) return 0;
+        if (X<o.X) return -1;
+        return 1;
+    }
 }
