@@ -26,7 +26,7 @@ import java.util.Enumeration;
 
 import rene.util.MyVector;
 import rene.util.xml.XmlWriter;
-import rene.zirkel.Zirkel;
+import rene.gui.Global;
 import rene.zirkel.ZirkelCanvas;
 import rene.zirkel.constructors.ObjectConstructor;
 import rene.zirkel.objects.ConstructionObject;
@@ -72,7 +72,7 @@ public class BreakpointAnimator extends ObjectConstructor implements Runnable {
 
 	@Override
 	public void showStatus(final ZirkelCanvas zc) {
-		zc.showStatus(Zirkel.name("message.animatebreak"));
+		zc.showStatus(Global.name("message.animatebreak"));
 	}
 
 	public void save(final XmlWriter xml) {
