@@ -29,10 +29,9 @@ This file is part of C.a.R. software.
 import java.awt.event.MouseEvent;
 import java.util.Vector;
 
-import rene.zirkel.Zirkel;
+import rene.gui.Global;
 import rene.zirkel.ZirkelCanvas;
 import rene.zirkel.constructors.ObjectConstructor;
-import rene.zirkel.dialogs.ObjectsEditDialog;
 import rene.zirkel.objects.ConstructionObject;
 
 public class Ruler extends ObjectConstructor {
@@ -41,39 +40,7 @@ public class Ruler extends ObjectConstructor {
 
 	public void mousePressed(final MouseEvent e, ConstructionObject o,
 			final ZirkelCanvas zc) {
-		zc.y(e.getY());
-		Other = (e.isShiftDown() && o == null);
-		if (o == null) {
-			o = zc.selectObject(e.getX(), e.getY());
-			if (o == null)
-				return;
-		}
-		if (o.isKeep())
-			return;
-		if (Other) {
-			if (V == null)
-				V = new Vector();
-			V.addElement(o);
-			o.setSelected(true);
-			zc.repaint();
-			return;
-		}
-		if (V != null) {
-			V.addElement(o);
-			o.setSelected(true);
-			final ObjectsEditDialog d = new ObjectsEditDialog(zc.getFrame(), V);
-			zc.clearSelected();
-			d.setVisible(true);
-		} else {
-			final String oldname = o.getName();
-			o.edit(zc);
-			if (!oldname.equals(o.getName()))
-				zc.updateTexts(o, oldname);
-		}
-		V = null;
-		Other = false;
-		zc.validate();
-		zc.repaint();
+		
 	}
 
 	@Override
@@ -89,7 +56,7 @@ public class Ruler extends ObjectConstructor {
 
 	@Override
 	public void showStatus(final ZirkelCanvas zc) {
-		zc.showStatus(Zirkel.name("message.edit"));
+		zc.showStatus(Global.name("message.edit"));
 	}
 
 	@Override
